/* eslint-disable no-unused-vars */
// Set globals
/* global describe it log pronghornProps */

// include required items for testing & logging
const assert = require('assert');
const fs = require('fs');
const mocha = require('mocha');
const winston = require('winston');

// stub and attemptTimeout are used throughout the code so set them here
let logLevel = 'none';
const stub = true;
const isRapidFail = false;
const isSaveMockData = false;
const attemptTimeout = 5000;

// these variables can be changed to run in integrated mode so easier to set them here
// always check these in with bogus data!!!
const host = 'replace.hostorip.here';
const username = 'username';
const password = 'password';
const protocol = 'http';
const port = 80;
const sslenable = false;
const sslinvalid = false;

// these are the adapter properties. You generally should not need to alter
// any of these after they are initially set up
global.pronghornProps = {
  pathProps: {
    encrypted: false
  },
  adapterProps: {
    adapters: [{
      id: 'Test-gitlab',
      type: 'Gitlab',
      properties: {
        host,
        port,
        base_path: '//api',
        version: 'vv3',
        cache_location: 'none',
        protocol,
        stub,
        authentication: {
          auth_method: 'no_authentication',
          username,
          password,
          token: '',
          token_timeout: -1,
          token_cache: 'local',
          invalid_token_error: 401,
          auth_field: 'header.headers.Authorization',
          auth_field_format: 'Basic {b64}{username}:{password}{/b64}'
        },
        healthcheck: {
          type: 'none',
          frequency: 60000
        },
        throttle: {
          throttle_enabled: false,
          number_pronghorns: 1,
          sync_async: 'sync',
          max_in_queue: 1000,
          concurrent_max: 1,
          expire_timeout: 0,
          avg_runtime: 200
        },
        request: {
          number_retries: 3,
          limit_retry_error: 0,
          failover_codes: [],
          attempt_timeout: attemptTimeout,
          healthcheck_on_timeout: true,
          archiving: false
        },
        proxy: {
          enabled: false,
          host: '',
          port: 1,
          protocol: 'http'
        },
        ssl: {
          ecdhCurve: '',
          enabled: sslenable,
          accept_invalid_cert: sslinvalid,
          ca_file: '',
          secure_protocol: '',
          ciphers: ''
        }
      }
    }]
  }
};

global.$HOME = `${__dirname}/../..`;

// set the log levels that Pronghorn uses, spam and trace are not defaulted in so without
// this you may error on log.trace calls.
const myCustomLevels = {
  levels: {
    spam: 6,
    trace: 5,
    debug: 4,
    info: 3,
    warn: 2,
    error: 1,
    none: 0
  }
};

// need to see if there is a log level passed in
process.argv.forEach((val) => {
  // is there a log level defined to be passed in?
  if (val.indexOf('--LOG') === 0) {
    // get the desired log level
    const inputVal = val.split('=')[1];

    // validate the log level is supported, if so set it
    if (Object.hasOwnProperty.call(myCustomLevels.levels, inputVal)) {
      logLevel = inputVal;
    }
  }
});

// need to set global logging
global.log = new (winston.Logger)({
  level: logLevel,
  levels: myCustomLevels.levels,
  transports: [
    new winston.transports.Console()
  ]
});

/**
 * Runs the common asserts for test
 */
function runCommonAsserts(data, error) {
  assert.equal(undefined, error);
  assert.notEqual(undefined, data);
  assert.notEqual(null, data);
  assert.notEqual(undefined, data.response);
  assert.notEqual(null, data.response);
}

/**
 * Runs the error asserts for the test
 */
function runErrorAsserts(data, error, code, origin, displayStr) {
  assert.equal(null, data);
  assert.notEqual(undefined, error);
  assert.notEqual(null, error);
  assert.notEqual(undefined, error.IAPerror);
  assert.notEqual(null, error.IAPerror);
  assert.notEqual(undefined, error.IAPerror.displayString);
  assert.notEqual(null, error.IAPerror.displayString);
  assert.equal(code, error.icode);
  assert.equal(origin, error.IAPerror.origin);
  assert.equal(displayStr, error.IAPerror.displayString);
}

/**
 * @function saveMockData
 * Attempts to take data from responses and place them in MockDataFiles to help create Mockdata.
 * Note, this was built based on entity file structure for Adapter-Engine 1.6.x
 * @param {string} entityName - Name of the entity saving mock data for
 * @param {string} actionName -  Name of the action saving mock data for
 * @param {string} descriptor -  Something to describe this test (used as a type)
 * @param {string or object} responseData - The data to put in the mock file.
 */
function saveMockData(entityName, actionName, descriptor, responseData) {
  // do not need to save mockdata if we are running in stub mode (already has mock data) or if told not to save
  if (stub || !isSaveMockData) {
    return false;
  }

  // must have a response in order to store the response
  if (responseData && responseData.response) {
    const data = responseData.response;

    try {
      const base = `./entities/${entityName}/`;
      const filename = `mockdatafiles/${actionName}-${descriptor}.json`;

      // make the mockdatafiles folder if it doesn't exist
      if (!fs.existsSync(`${base}mockdatafiles/`)) {
        fs.mkdirSync(`${base}mockdatafiles/`);
      }

      // write the data we retrieved
      fs.writeFile(base + filename, JSON.stringify(data, null, 2), 'utf8', (errWritingMock) => {
        if (errWritingMock) throw errWritingMock;

        // update the action file to reflect the changes. Note: We're replacing the default object for now!
        fs.readFile(`${base}action.json`, (errRead, content) => {
          if (errRead) throw errRead;

          // parse the action file into JSON
          const parsedJson = JSON.parse(content);

          // The object update we'll write in.
          const responseObj = {
            type: descriptor,
            key: '',
            mockFile: filename
          };

          // get the object for method we're trying to change.
          const currentMethodAction = parsedJson.actions.find(obj => obj.name === actionName);

          // if the method was not found - should never happen but...
          if (!currentMethodAction) {
            throw Error('Can\'t find an action for this method in the provided entity.');
          }

          // if there is a response object, we want to replace the Response object. Otherwise we'll create one.
          const actionResponseObj = currentMethodAction.responseObjects.find(obj => obj.type === descriptor);

          // Add the action responseObj back into the array of response objects.
          if (!actionResponseObj) {
            // save the new response object
            currentMethodAction.responseObjects = [responseObj];
          } else {
            // update the location of the mock data file
            actionResponseObj.mockFile = responseObj.mockFile;
          }

          // Save results
          fs.writeFile(`${base}action.json`, JSON.stringify(parsedJson, null, 2), (err) => {
            if (err) throw err;
          });
        });
      });
    } catch (e) {
      log.debug(`Failed to save mock data for ${actionName}. ${e.message}`);
      return false;
    }
  }

  // no response to save
  log.debug(`No data passed to save into mockdata for ${actionName}`);
  return false;
}


// require the adapter that we are going to be using
const Gitlab = require('../../adapter.js');

// begin the testing - these should be pretty well defined between the describe and the it!
describe('[integration] Gitlab Adapter Test', () => {
  describe('Gitlab Class Tests', () => {
    const a = new Gitlab(
      pronghornProps.adapterProps.adapters[0].id,
      pronghornProps.adapterProps.adapters[0].properties
    );

    if (isRapidFail) {
      const state = {};
      state.passed = true;

      mocha.afterEach(function x() {
        state.passed = state.passed
        && (this.currentTest.state === 'passed');
      });
      mocha.beforeEach(function x() {
        if (!state.passed) {
          return this.currentTest.skip();
        }
        return true;
      });
    }

    describe('#class instance created', () => {
      it('should be a class with properties', (done) => {
        assert.notEqual(null, a);
        assert.notEqual(undefined, a);
        assert.notEqual(null, a.allProps);
        const check = global.pronghornProps.adapterProps.adapters[0].properties.healthcheck.type;
        assert.equal(check, a.healthcheckType);
        done();
      }).timeout(attemptTimeout);
    });

    describe('#connect', () => {
      it('should get connected - no healthcheck', (done) => {
        a.healthcheckType = 'none';
        a.connect();
        assert.equal(true, a.alive);
        done();
      });
      it('should get connected - startup healthcheck', (done) => {
        a.healthcheckType = 'startup';
        a.connect();
        assert.equal(true, a.alive);
        done();
      });
    });

    describe('#healthCheck', () => {
      it('should be healthy', (done) => {
        const p = new Promise((resolve) => {
          a.healthCheck(null, (data) => {
            assert.equal(true, a.healthy);
            saveMockData('system', 'healthcheck', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    /*
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    *** All code above this comment will be replaced during a migration ***
    ******************* DO NOT REMOVE THIS COMMENT BLOCK ******************
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    */

    describe('#getV3Groups - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Groups('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.statistics);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'getV3Groups', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3Groups - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3Groups('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.statistics);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'postV3Groups', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsOwned - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsOwned('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.statistics);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'getV3GroupsOwned', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.path);
              assert.equal('object', typeof data.response.projects);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('object', typeof data.response.shared_projects);
              assert.equal('string', data.response.statistics);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'getV3GroupsId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3GroupsId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3GroupsId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.statistics);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'putV3GroupsId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3GroupsId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3GroupsId('fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'deleteV3GroupsId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsIdAccessRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdAccessRequests('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.requested_at);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'getV3GroupsIdAccessRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3GroupsIdAccessRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3GroupsIdAccessRequests('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.requested_at);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'postV3GroupsIdAccessRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3GroupsIdAccessRequestsUserId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3GroupsIdAccessRequestsUserId('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'deleteV3GroupsIdAccessRequestsUserId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3GroupsIdAccessRequestsUserIdApprove - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3GroupsIdAccessRequestsUserIdApprove('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.access_level);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'putV3GroupsIdAccessRequestsUserIdApprove', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsIdIssues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdIssues('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.confidential);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'getV3GroupsIdIssues', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsIdMembers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdMembers('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.access_level);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'getV3GroupsIdMembers', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3GroupsIdMembers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3GroupsIdMembers('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.access_level);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'postV3GroupsIdMembers', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsIdMembersUserId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdMembersUserId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.access_level);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'getV3GroupsIdMembersUserId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3GroupsIdMembersUserId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3GroupsIdMembersUserId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.access_level);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'putV3GroupsIdMembersUserId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3GroupsIdMembersUserId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3GroupsIdMembersUserId('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'deleteV3GroupsIdMembersUserId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsIdNotificationSettings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdNotificationSettings('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.events);
              assert.equal('string', data.response.level);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'getV3GroupsIdNotificationSettings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3GroupsIdNotificationSettings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3GroupsIdNotificationSettings('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.events);
              assert.equal('string', data.response.level);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'putV3GroupsIdNotificationSettings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsIdProjects - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdProjects('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.archived);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.builds_enabled);
              assert.equal('string', data.response.container_registry_enabled);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.creator_id);
              assert.equal('string', data.response.default_branch);
              assert.equal('string', data.response.description);
              assert.equal('object', typeof data.response.forked_from_project);
              assert.equal('string', data.response.forks_count);
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_enabled);
              assert.equal('string', data.response.last_activity_at);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.merge_requests_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('object', typeof data.response.namespace);
              assert.equal('string', data.response.only_allow_merge_if_all_discussions_are_resolved);
              assert.equal('string', data.response.only_allow_merge_if_build_succeeds);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('object', typeof data.response.owner);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.public);
              assert.equal('string', data.response.public_builds);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.runners_token);
              assert.equal('string', data.response.shared_runners_enabled);
              assert.equal('string', data.response.shared_with_groups);
              assert.equal('string', data.response.snippets_enabled);
              assert.equal('string', data.response.ssh_url_to_repo);
              assert.equal('string', data.response.star_count);
              assert.equal('object', typeof data.response.statistics);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.wiki_enabled);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'getV3GroupsIdProjects', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3GroupsIdProjectsProjectId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3GroupsIdProjectsProjectId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.path);
              assert.equal('object', typeof data.response.projects);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('object', typeof data.response.shared_projects);
              assert.equal('string', data.response.statistics);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('groups', 'postV3GroupsIdProjectsProjectId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Projects - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Projects('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3Projects', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3Projects - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3Projects('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.archived);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.builds_enabled);
              assert.equal('string', data.response.container_registry_enabled);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.creator_id);
              assert.equal('string', data.response.default_branch);
              assert.equal('string', data.response.description);
              assert.equal('object', typeof data.response.forked_from_project);
              assert.equal('string', data.response.forks_count);
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_enabled);
              assert.equal('string', data.response.last_activity_at);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.merge_requests_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('object', typeof data.response.namespace);
              assert.equal('string', data.response.only_allow_merge_if_all_discussions_are_resolved);
              assert.equal('string', data.response.only_allow_merge_if_build_succeeds);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('object', typeof data.response.owner);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.public);
              assert.equal('string', data.response.public_builds);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.runners_token);
              assert.equal('string', data.response.shared_runners_enabled);
              assert.equal('string', data.response.shared_with_groups);
              assert.equal('string', data.response.snippets_enabled);
              assert.equal('string', data.response.ssh_url_to_repo);
              assert.equal('string', data.response.star_count);
              assert.equal('object', typeof data.response.statistics);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.wiki_enabled);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3Projects', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsAll - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsAll('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsAll', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsForkId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsForkId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.archived);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.builds_enabled);
              assert.equal('string', data.response.container_registry_enabled);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.creator_id);
              assert.equal('string', data.response.default_branch);
              assert.equal('string', data.response.description);
              assert.equal('object', typeof data.response.forked_from_project);
              assert.equal('string', data.response.forks_count);
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_enabled);
              assert.equal('string', data.response.last_activity_at);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.merge_requests_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('object', typeof data.response.namespace);
              assert.equal('string', data.response.only_allow_merge_if_all_discussions_are_resolved);
              assert.equal('string', data.response.only_allow_merge_if_build_succeeds);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('object', typeof data.response.owner);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.public);
              assert.equal('string', data.response.public_builds);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.runners_token);
              assert.equal('string', data.response.shared_runners_enabled);
              assert.equal('string', data.response.shared_with_groups);
              assert.equal('string', data.response.snippets_enabled);
              assert.equal('string', data.response.ssh_url_to_repo);
              assert.equal('string', data.response.star_count);
              assert.equal('object', typeof data.response.statistics);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.wiki_enabled);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsForkId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsOwned - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsOwned('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsOwned', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsSearchQuery - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsSearchQuery('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.archived);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.builds_enabled);
              assert.equal('string', data.response.container_registry_enabled);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.creator_id);
              assert.equal('string', data.response.default_branch);
              assert.equal('string', data.response.description);
              assert.equal('object', typeof data.response.forked_from_project);
              assert.equal('string', data.response.forks_count);
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_enabled);
              assert.equal('string', data.response.last_activity_at);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.merge_requests_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('object', typeof data.response.namespace);
              assert.equal('string', data.response.only_allow_merge_if_all_discussions_are_resolved);
              assert.equal('string', data.response.only_allow_merge_if_build_succeeds);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('object', typeof data.response.owner);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.public);
              assert.equal('string', data.response.public_builds);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.runners_token);
              assert.equal('string', data.response.shared_runners_enabled);
              assert.equal('string', data.response.shared_with_groups);
              assert.equal('string', data.response.snippets_enabled);
              assert.equal('string', data.response.ssh_url_to_repo);
              assert.equal('string', data.response.star_count);
              assert.equal('object', typeof data.response.statistics);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.wiki_enabled);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsSearchQuery', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsStarred - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsStarred('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsStarred', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsUserUserId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsUserUserId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.archived);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.builds_enabled);
              assert.equal('string', data.response.container_registry_enabled);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.creator_id);
              assert.equal('string', data.response.default_branch);
              assert.equal('string', data.response.description);
              assert.equal('object', typeof data.response.forked_from_project);
              assert.equal('string', data.response.forks_count);
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_enabled);
              assert.equal('string', data.response.last_activity_at);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.merge_requests_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('object', typeof data.response.namespace);
              assert.equal('string', data.response.only_allow_merge_if_all_discussions_are_resolved);
              assert.equal('string', data.response.only_allow_merge_if_build_succeeds);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('object', typeof data.response.owner);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.public);
              assert.equal('string', data.response.public_builds);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.runners_token);
              assert.equal('string', data.response.shared_runners_enabled);
              assert.equal('string', data.response.shared_with_groups);
              assert.equal('string', data.response.snippets_enabled);
              assert.equal('string', data.response.ssh_url_to_repo);
              assert.equal('string', data.response.star_count);
              assert.equal('object', typeof data.response.statistics);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.wiki_enabled);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsUserUserId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsVisible - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsVisible('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsVisible', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.archived);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.builds_enabled);
              assert.equal('string', data.response.container_registry_enabled);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.creator_id);
              assert.equal('string', data.response.default_branch);
              assert.equal('string', data.response.description);
              assert.equal('object', typeof data.response.forked_from_project);
              assert.equal('string', data.response.forks_count);
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_enabled);
              assert.equal('string', data.response.last_activity_at);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.merge_requests_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('object', typeof data.response.namespace);
              assert.equal('string', data.response.only_allow_merge_if_all_discussions_are_resolved);
              assert.equal('string', data.response.only_allow_merge_if_build_succeeds);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('object', typeof data.response.owner);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.permissions);
              assert.equal('string', data.response.public);
              assert.equal('string', data.response.public_builds);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.runners_token);
              assert.equal('string', data.response.shared_runners_enabled);
              assert.equal('string', data.response.shared_with_groups);
              assert.equal('string', data.response.snippets_enabled);
              assert.equal('string', data.response.ssh_url_to_repo);
              assert.equal('string', data.response.star_count);
              assert.equal('object', typeof data.response.statistics);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.wiki_enabled);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.archived);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.builds_enabled);
              assert.equal('string', data.response.container_registry_enabled);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.creator_id);
              assert.equal('string', data.response.default_branch);
              assert.equal('string', data.response.description);
              assert.equal('object', typeof data.response.forked_from_project);
              assert.equal('string', data.response.forks_count);
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_enabled);
              assert.equal('string', data.response.last_activity_at);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.merge_requests_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('object', typeof data.response.namespace);
              assert.equal('string', data.response.only_allow_merge_if_all_discussions_are_resolved);
              assert.equal('string', data.response.only_allow_merge_if_build_succeeds);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('object', typeof data.response.owner);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.public);
              assert.equal('string', data.response.public_builds);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.runners_token);
              assert.equal('string', data.response.shared_runners_enabled);
              assert.equal('string', data.response.shared_with_groups);
              assert.equal('string', data.response.snippets_enabled);
              assert.equal('string', data.response.ssh_url_to_repo);
              assert.equal('string', data.response.star_count);
              assert.equal('object', typeof data.response.statistics);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.wiki_enabled);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsId('fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdAccessRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdAccessRequests('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.requested_at);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdAccessRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdAccessRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdAccessRequests('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.requested_at);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdAccessRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdAccessRequestsUserId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdAccessRequestsUserId('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdAccessRequestsUserId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdAccessRequestsUserIdApprove - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdAccessRequestsUserIdApprove('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.access_level);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdAccessRequestsUserIdApprove', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdArchive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdArchive('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.archived);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.builds_enabled);
              assert.equal('string', data.response.container_registry_enabled);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.creator_id);
              assert.equal('string', data.response.default_branch);
              assert.equal('string', data.response.description);
              assert.equal('object', typeof data.response.forked_from_project);
              assert.equal('string', data.response.forks_count);
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_enabled);
              assert.equal('string', data.response.last_activity_at);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.merge_requests_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('object', typeof data.response.namespace);
              assert.equal('string', data.response.only_allow_merge_if_all_discussions_are_resolved);
              assert.equal('string', data.response.only_allow_merge_if_build_succeeds);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('object', typeof data.response.owner);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.public);
              assert.equal('string', data.response.public_builds);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.runners_token);
              assert.equal('string', data.response.shared_runners_enabled);
              assert.equal('string', data.response.shared_with_groups);
              assert.equal('string', data.response.snippets_enabled);
              assert.equal('string', data.response.ssh_url_to_repo);
              assert.equal('string', data.response.star_count);
              assert.equal('object', typeof data.response.statistics);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.wiki_enabled);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdArchive', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBoards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBoards('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.lists);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdBoards', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBoardsBoardIdLists - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBoardsBoardIdLists('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.label);
              assert.equal('string', data.response.position);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdBoardsBoardIdLists', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdBoardsBoardIdLists - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBoardsBoardIdLists('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.label);
              assert.equal('string', data.response.position);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdBoardsBoardIdLists', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBoardsBoardIdListsListId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBoardsBoardIdListsListId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.label);
              assert.equal('string', data.response.position);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdBoardsBoardIdListsListId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdBoardsBoardIdListsListId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdBoardsBoardIdListsListId('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.label);
              assert.equal('string', data.response.position);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdBoardsBoardIdListsListId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdBoardsBoardIdListsListId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdBoardsBoardIdListsListId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.label);
              assert.equal('string', data.response.position);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdBoardsBoardIdListsListId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBuilds - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuilds('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.artifacts_file);
              assert.equal('object', typeof data.response.commit);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.pipeline);
              assert.equal('string', data.response.ref);
              assert.equal('object', typeof data.response.runner);
              assert.equal('string', data.response.stage);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdBuilds', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBuildsArtifactsRefNameDownload - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsArtifactsRefNameDownload('fakedata', 'fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdBuildsArtifactsRefNameDownload', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBuildsBuildId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsBuildId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.artifacts_file);
              assert.equal('object', typeof data.response.commit);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.pipeline);
              assert.equal('string', data.response.ref);
              assert.equal('object', typeof data.response.runner);
              assert.equal('string', data.response.stage);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdBuildsBuildId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBuildsBuildIdArtifacts - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsBuildIdArtifacts('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdBuildsBuildIdArtifacts', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdBuildsBuildIdArtifactsKeep - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdArtifactsKeep('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.artifacts_file);
              assert.equal('object', typeof data.response.commit);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.pipeline);
              assert.equal('string', data.response.ref);
              assert.equal('object', typeof data.response.runner);
              assert.equal('string', data.response.stage);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdBuildsBuildIdArtifactsKeep', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdBuildsBuildIdCancel - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdCancel('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.artifacts_file);
              assert.equal('object', typeof data.response.commit);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.pipeline);
              assert.equal('string', data.response.ref);
              assert.equal('object', typeof data.response.runner);
              assert.equal('string', data.response.stage);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdBuildsBuildIdCancel', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdBuildsBuildIdErase - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdErase('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.artifacts_file);
              assert.equal('object', typeof data.response.commit);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.pipeline);
              assert.equal('string', data.response.ref);
              assert.equal('object', typeof data.response.runner);
              assert.equal('string', data.response.stage);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdBuildsBuildIdErase', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdBuildsBuildIdPlay - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdPlay('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.artifacts_file);
              assert.equal('object', typeof data.response.commit);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.pipeline);
              assert.equal('string', data.response.ref);
              assert.equal('object', typeof data.response.runner);
              assert.equal('string', data.response.stage);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdBuildsBuildIdPlay', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdBuildsBuildIdRetry - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdRetry('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.artifacts_file);
              assert.equal('object', typeof data.response.commit);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.pipeline);
              assert.equal('string', data.response.ref);
              assert.equal('object', typeof data.response.runner);
              assert.equal('string', data.response.stage);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdBuildsBuildIdRetry', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBuildsBuildIdTrace - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsBuildIdTrace('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdBuildsBuildIdTrace', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdDeployKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdDeployKeys('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdDeployKeys', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdDeployKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdDeployKeys('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdDeployKeys', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdDeployKeysKeyId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdDeployKeysKeyId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdDeployKeysKeyId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdDeployKeysKeyId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdDeployKeysKeyId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdDeployKeysKeyId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdDeployKeysKeyIdDisable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdDeployKeysKeyIdDisable('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdDeployKeysKeyIdDisable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdDeployKeysKeyIdEnable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdDeployKeysKeyIdEnable('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdDeployKeysKeyIdEnable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdDeployments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdDeployments('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('object', typeof data.response.deployable);
              assert.equal('object', typeof data.response.environment);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.ref);
              assert.equal('string', data.response.sha);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdDeployments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdDeploymentsDeploymentId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdDeploymentsDeploymentId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('object', typeof data.response.deployable);
              assert.equal('object', typeof data.response.environment);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.ref);
              assert.equal('string', data.response.sha);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdDeploymentsDeploymentId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdEnvironments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdEnvironments('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.external_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.project);
              assert.equal('string', data.response.slug);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdEnvironments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdEnvironments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdEnvironments('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.external_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.project);
              assert.equal('string', data.response.slug);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdEnvironments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdEnvironmentsEnvironmentId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdEnvironmentsEnvironmentId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.external_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.project);
              assert.equal('string', data.response.slug);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdEnvironmentsEnvironmentId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdEnvironmentsEnvironmentId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdEnvironmentsEnvironmentId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.external_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.project);
              assert.equal('string', data.response.slug);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdEnvironmentsEnvironmentId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdEvents - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdEvents('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.action_name);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.author_id);
              assert.equal('string', data.response.author_username);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.data);
              assert.equal('object', typeof data.response.note);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.target_id);
              assert.equal('string', data.response.target_title);
              assert.equal('string', data.response.target_type);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdEvents', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdFork - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdFork('fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdFork', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdForkForkedFromId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdForkForkedFromId('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdForkForkedFromId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdHooks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdHooks('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.build_events);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.enable_ssl_verification);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_events);
              assert.equal('string', data.response.merge_requests_events);
              assert.equal('string', data.response.note_events);
              assert.equal('string', data.response.pipeline_events);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.push_events);
              assert.equal('string', data.response.tag_push_events);
              assert.equal('string', data.response.url);
              assert.equal('string', data.response.wiki_page_events);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdHooks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdHooks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdHooks('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.build_events);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.enable_ssl_verification);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_events);
              assert.equal('string', data.response.merge_requests_events);
              assert.equal('string', data.response.note_events);
              assert.equal('string', data.response.pipeline_events);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.push_events);
              assert.equal('string', data.response.tag_push_events);
              assert.equal('string', data.response.url);
              assert.equal('string', data.response.wiki_page_events);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdHooks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdHooksHookId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdHooksHookId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.build_events);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.enable_ssl_verification);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_events);
              assert.equal('string', data.response.merge_requests_events);
              assert.equal('string', data.response.note_events);
              assert.equal('string', data.response.pipeline_events);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.push_events);
              assert.equal('string', data.response.tag_push_events);
              assert.equal('string', data.response.url);
              assert.equal('string', data.response.wiki_page_events);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdHooksHookId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdHooksHookId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdHooksHookId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.build_events);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.enable_ssl_verification);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_events);
              assert.equal('string', data.response.merge_requests_events);
              assert.equal('string', data.response.note_events);
              assert.equal('string', data.response.pipeline_events);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.push_events);
              assert.equal('string', data.response.tag_push_events);
              assert.equal('string', data.response.url);
              assert.equal('string', data.response.wiki_page_events);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdHooksHookId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdHooksHookId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdHooksHookId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.build_events);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.enable_ssl_verification);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_events);
              assert.equal('string', data.response.merge_requests_events);
              assert.equal('string', data.response.note_events);
              assert.equal('string', data.response.pipeline_events);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.push_events);
              assert.equal('string', data.response.tag_push_events);
              assert.equal('string', data.response.url);
              assert.equal('string', data.response.wiki_page_events);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdHooksHookId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssues('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.confidential);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdIssues', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssues('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.confidential);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdIssues', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesIssueId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.confidential);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdIssuesIssueId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdIssuesIssueId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdIssuesIssueId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.confidential);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdIssuesIssueId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdIssuesIssueId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesIssueId('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdIssuesIssueId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdAddSpentTime - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdAddSpentTime('fakedata', 'fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdIssuesIssueIdAddSpentTime', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesIssueIdAwardEmoji - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdAwardEmoji('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdIssuesIssueIdAwardEmoji', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdAwardEmoji - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdAwardEmoji('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdIssuesIssueIdAwardEmoji', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesIssueIdAwardEmojiAwardId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdAwardEmojiAwardId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdIssuesIssueIdAwardEmojiAwardId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdIssuesIssueIdAwardEmojiAwardId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesIssueIdAwardEmojiAwardId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdIssuesIssueIdAwardEmojiAwardId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdMove - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdMove('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.confidential);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdIssuesIssueIdMove', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdResetSpentTime - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdResetSpentTime('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdIssuesIssueIdResetSpentTime', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdResetTimeEstimate - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdResetTimeEstimate('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdIssuesIssueIdResetTimeEstimate', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdTimeEstimate - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdTimeEstimate('fakedata', 'fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdIssuesIssueIdTimeEstimate', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesIssueIdTimeStats - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdTimeStats('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdIssuesIssueIdTimeStats', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdTodo - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdTodo('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.action_name);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.project);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.target);
              assert.equal('string', data.response.target_type);
              assert.equal('string', data.response.target_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdIssuesIssueIdTodo', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesNoteableIdNotes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesNoteableIdNotes('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdIssuesNoteableIdNotes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesNoteableIdNotes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesNoteableIdNotes('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdIssuesNoteableIdNotes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesNoteableIdNotesNoteId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesNoteableIdNotesNoteId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdIssuesNoteableIdNotesNoteId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdIssuesNoteableIdNotesNoteId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdIssuesNoteableIdNotesNoteId('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdIssuesNoteableIdNotesNoteId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdIssuesNoteableIdNotesNoteId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesNoteableIdNotesNoteId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdIssuesNoteableIdNotesNoteId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesSubscribableIdSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesSubscribableIdSubscription('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.confidential);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdIssuesSubscribableIdSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdIssuesSubscribableIdSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesSubscribableIdSubscription('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.confidential);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdIssuesSubscribableIdSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdKeys('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdKeys', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdKeys('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdKeys', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdKeysKeyId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdKeysKeyId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdKeysKeyId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdKeysKeyId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdKeysKeyId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdKeysKeyId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdKeysKeyIdDisable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdKeysKeyIdDisable('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdKeysKeyIdDisable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdKeysKeyIdEnable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdKeysKeyIdEnable('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdKeysKeyIdEnable', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdLabels - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdLabels('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.closed_issues_count);
              assert.equal('string', data.response.color);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('string', data.response.open_merge_requests_count);
              assert.equal('string', data.response.priority);
              assert.equal('string', data.response.subscribed);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdLabels', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdLabels - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdLabels('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.closed_issues_count);
              assert.equal('string', data.response.color);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('string', data.response.open_merge_requests_count);
              assert.equal('string', data.response.priority);
              assert.equal('string', data.response.subscribed);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdLabels', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdLabels - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdLabels('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.closed_issues_count);
              assert.equal('string', data.response.color);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('string', data.response.open_merge_requests_count);
              assert.equal('string', data.response.priority);
              assert.equal('string', data.response.subscribed);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdLabels', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdLabels - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdLabels('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.closed_issues_count);
              assert.equal('string', data.response.color);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('string', data.response.open_merge_requests_count);
              assert.equal('string', data.response.priority);
              assert.equal('string', data.response.subscribed);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdLabels', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdLabelsSubscribableIdSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdLabelsSubscribableIdSubscription('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.closed_issues_count);
              assert.equal('string', data.response.color);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('string', data.response.open_merge_requests_count);
              assert.equal('string', data.response.priority);
              assert.equal('string', data.response.subscribed);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdLabelsSubscribableIdSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdLabelsSubscribableIdSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdLabelsSubscribableIdSubscription('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.closed_issues_count);
              assert.equal('string', data.response.color);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('string', data.response.open_merge_requests_count);
              assert.equal('string', data.response.priority);
              assert.equal('string', data.response.subscribed);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdLabelsSubscribableIdSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMembers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMembers('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.access_level);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMembers', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMembers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMembers('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.access_level);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMembers', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMembersUserId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMembersUserId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.access_level);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMembersUserId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMembersUserId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMembersUserId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.access_level);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdMembersUserId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMembersUserId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMembersUserId('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdMembersUserId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestMergeRequestId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestMergeRequestId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMergeRequestMergeRequestId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestMergeRequestId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdMergeRequestMergeRequestId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestMergeRequestIdCancelMergeWhenBuildSucceeds - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestMergeRequestIdCancelMergeWhenBuildSucceeds('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestMergeRequestIdCancelMergeWhenBuildSucceeds', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestMergeRequestIdChanges - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestIdChanges('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('object', typeof data.response.changes);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestMergeRequestIdChanges', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestMergeRequestIdClosesIssues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestIdClosesIssues('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.note);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestMergeRequestIdClosesIssues', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestMergeRequestIdComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestIdComments('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.note);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestMergeRequestIdComments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestMergeRequestIdComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestMergeRequestIdComments('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.note);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestMergeRequestIdComments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestMergeRequestIdCommits - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestIdCommits('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.author_email);
              assert.equal('string', data.response.author_name);
              assert.equal('string', data.response.committer_email);
              assert.equal('string', data.response.committer_name);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.message);
              assert.equal('string', data.response.short_id);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestMergeRequestIdCommits', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMergeRequestMergeRequestIdMerge - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestMergeRequestIdMerge('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdMergeRequestMergeRequestIdMerge', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestSubscribableIdSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestSubscribableIdSubscription('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestSubscribableIdSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMergeRequestSubscribableIdSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestSubscribableIdSubscription('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdMergeRequestSubscribableIdSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequests('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequests('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequests', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsMergeRequestId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMergeRequestsMergeRequestId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestsMergeRequestId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdMergeRequestsMergeRequestId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMergeRequestsMergeRequestId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsMergeRequestId('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdMergeRequestsMergeRequestId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdAddSpentTime - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdAddSpentTime('fakedata', 'fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestsMergeRequestIdAddSpentTime', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdCancelMergeWhenBuildSucceeds - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdCancelMergeWhenBuildSucceeds('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestsMergeRequestIdCancelMergeWhenBuildSucceeds', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdChanges - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdChanges('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('object', typeof data.response.changes);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsMergeRequestIdChanges', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdClosesIssues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdClosesIssues('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.note);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsMergeRequestIdClosesIssues', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdComments('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.note);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsMergeRequestIdComments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdComments('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.note);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestsMergeRequestIdComments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdCommits - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdCommits('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.author_email);
              assert.equal('string', data.response.author_name);
              assert.equal('string', data.response.committer_email);
              assert.equal('string', data.response.committer_name);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.message);
              assert.equal('string', data.response.short_id);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsMergeRequestIdCommits', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMergeRequestsMergeRequestIdMerge - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestsMergeRequestIdMerge('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdMergeRequestsMergeRequestIdMerge', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdResetSpentTime - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdResetSpentTime('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestsMergeRequestIdResetSpentTime', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdResetTimeEstimate - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdResetTimeEstimate('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestsMergeRequestIdResetTimeEstimate', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdTimeEstimate - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdTimeEstimate('fakedata', 'fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestsMergeRequestIdTimeEstimate', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdTimeStats - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdTimeStats('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsMergeRequestIdTimeStats', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdTodo - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdTodo('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.action_name);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.project);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.target);
              assert.equal('string', data.response.target_type);
              assert.equal('string', data.response.target_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestsMergeRequestIdTodo', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdVersions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdVersions('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.base_commit_sha);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.head_commit_sha);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.merge_request_id);
              assert.equal('string', data.response.real_size);
              assert.equal('string', data.response.start_commit_sha);
              assert.equal('string', data.response.state);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsMergeRequestIdVersions', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdVersionsVersionId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdVersionsVersionId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.base_commit_sha);
              assert.equal('object', typeof data.response.commits);
              assert.equal('string', data.response.created_at);
              assert.equal('object', typeof data.response.diffs);
              assert.equal('string', data.response.head_commit_sha);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.merge_request_id);
              assert.equal('string', data.response.real_size);
              assert.equal('string', data.response.start_commit_sha);
              assert.equal('string', data.response.state);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsMergeRequestIdVersionsVersionId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsNoteableIdNotes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsNoteableIdNotes('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsNoteableIdNotes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsNoteableIdNotes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsNoteableIdNotes('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestsNoteableIdNotes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsNoteableIdNotesNoteId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsNoteableIdNotesNoteId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMergeRequestsNoteableIdNotesNoteId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsNoteableIdNotesNoteId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsSubscribableIdSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsSubscribableIdSubscription('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMergeRequestsSubscribableIdSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMergeRequestsSubscribableIdSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsSubscribableIdSubscription('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.force_remove_source_branch);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('string', data.response.merge_commit_sha);
              assert.equal('string', data.response.merge_status);
              assert.equal('string', data.response.merge_when_build_succeeds);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.should_remove_source_branch);
              assert.equal('string', data.response.source_branch);
              assert.equal('string', data.response.source_project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.target_branch);
              assert.equal('string', data.response.target_project_id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.work_in_progress);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdMergeRequestsSubscribableIdSubscription', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMilestones - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMilestones('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.start_date);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMilestones', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMilestones - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMilestones('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.start_date);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdMilestones', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMilestonesMilestoneId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMilestonesMilestoneId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.start_date);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMilestonesMilestoneId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMilestonesMilestoneId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMilestonesMilestoneId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.start_date);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdMilestonesMilestoneId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMilestonesMilestoneIdIssues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMilestonesMilestoneIdIssues('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.confidential);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdMilestonesMilestoneIdIssues', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdNotificationSettings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdNotificationSettings('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.events);
              assert.equal('string', data.response.level);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdNotificationSettings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdNotificationSettings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdNotificationSettings('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.events);
              assert.equal('string', data.response.level);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdNotificationSettings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdPipeline - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdPipeline('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.before_sha);
              assert.equal('string', data.response.committed_at);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.duration);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.ref);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
              assert.equal('string', data.response.yaml_errors);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdPipeline', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdPipelines - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdPipelines('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.before_sha);
              assert.equal('string', data.response.committed_at);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.duration);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.ref);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
              assert.equal('string', data.response.yaml_errors);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdPipelines', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdPipelinesPipelineId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdPipelinesPipelineId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.before_sha);
              assert.equal('string', data.response.committed_at);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.duration);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.ref);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
              assert.equal('string', data.response.yaml_errors);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdPipelinesPipelineId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdPipelinesPipelineIdCancel - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdPipelinesPipelineIdCancel('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.before_sha);
              assert.equal('string', data.response.committed_at);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.duration);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.ref);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
              assert.equal('string', data.response.yaml_errors);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdPipelinesPipelineIdCancel', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdPipelinesPipelineIdRetry - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdPipelinesPipelineIdRetry('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.before_sha);
              assert.equal('string', data.response.committed_at);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.duration);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.ref);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
              assert.equal('string', data.response.yaml_errors);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdPipelinesPipelineIdRetry', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryArchive - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryArchive('fakedata', 'fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryArchive', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryBlobsSha - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryBlobsSha('fakedata', 'fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryBlobsSha', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryBranches - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryBranches('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.commit);
              assert.equal('string', data.response.developers_can_merge);
              assert.equal('string', data.response.developers_can_push);
              assert.equal('string', data.response.merged);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.protected);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryBranches', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryBranches - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryBranches('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.commit);
              assert.equal('string', data.response.developers_can_merge);
              assert.equal('string', data.response.developers_can_push);
              assert.equal('string', data.response.merged);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.protected);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdRepositoryBranches', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryBranchesBranch - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryBranchesBranch('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.commit);
              assert.equal('string', data.response.developers_can_merge);
              assert.equal('string', data.response.developers_can_push);
              assert.equal('string', data.response.merged);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.protected);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryBranchesBranch', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdRepositoryBranchesBranch - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryBranchesBranch('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdRepositoryBranchesBranch', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdRepositoryBranchesBranchProtect - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryBranchesBranchProtect('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.commit);
              assert.equal('string', data.response.developers_can_merge);
              assert.equal('string', data.response.developers_can_push);
              assert.equal('string', data.response.merged);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.protected);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdRepositoryBranchesBranchProtect', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdRepositoryBranchesBranchUnprotect - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryBranchesBranchUnprotect('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.commit);
              assert.equal('string', data.response.developers_can_merge);
              assert.equal('string', data.response.developers_can_push);
              assert.equal('string', data.response.merged);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.protected);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdRepositoryBranchesBranchUnprotect', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommits - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommits('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.author_email);
              assert.equal('string', data.response.author_name);
              assert.equal('string', data.response.committer_email);
              assert.equal('string', data.response.committer_name);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.message);
              assert.equal('string', data.response.short_id);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryCommits', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryCommits - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryCommits('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.author_email);
              assert.equal('string', data.response.author_name);
              assert.equal('string', data.response.authored_date);
              assert.equal('string', data.response.committed_date);
              assert.equal('string', data.response.committer_email);
              assert.equal('string', data.response.committer_name);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.message);
              assert.equal('string', data.response.parent_ids);
              assert.equal('string', data.response.short_id);
              assert.equal('object', typeof data.response.stats);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdRepositoryCommits', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommitsSha - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsSha('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.author_email);
              assert.equal('string', data.response.author_name);
              assert.equal('string', data.response.authored_date);
              assert.equal('string', data.response.committed_date);
              assert.equal('string', data.response.committer_email);
              assert.equal('string', data.response.committer_name);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.message);
              assert.equal('string', data.response.parent_ids);
              assert.equal('string', data.response.short_id);
              assert.equal('object', typeof data.response.stats);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryCommitsSha', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommitsShaBlob - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaBlob('fakedata', 'fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryCommitsShaBlob', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommitsShaBuilds - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaBuilds('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.artifacts_file);
              assert.equal('object', typeof data.response.commit);
              assert.equal('string', data.response.coverage);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.pipeline);
              assert.equal('string', data.response.ref);
              assert.equal('object', typeof data.response.runner);
              assert.equal('string', data.response.stage);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.tag);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryCommitsShaBuilds', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryCommitsShaCherryPick - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryCommitsShaCherryPick('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.author_email);
              assert.equal('string', data.response.author_name);
              assert.equal('string', data.response.committer_email);
              assert.equal('string', data.response.committer_name);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.message);
              assert.equal('string', data.response.short_id);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdRepositoryCommitsShaCherryPick', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommitsShaComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaComments('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.line);
              assert.equal('string', data.response.line_type);
              assert.equal('string', data.response.note);
              assert.equal('string', data.response.path);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryCommitsShaComments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryCommitsShaComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryCommitsShaComments('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.line);
              assert.equal('string', data.response.line_type);
              assert.equal('string', data.response.note);
              assert.equal('string', data.response.path);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdRepositoryCommitsShaComments', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommitsShaDiff - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaDiff('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryCommitsShaDiff', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommitsShaStatuses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaStatuses('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.allow_failure);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.ref);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.target_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryCommitsShaStatuses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCompare - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCompare('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.commit);
              assert.equal('object', typeof data.response.commits);
              assert.equal('string', data.response.compare_same_ref);
              assert.equal('string', data.response.compare_timeout);
              assert.equal('object', typeof data.response.diffs);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryCompare', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryContributors - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryContributors('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.additions);
              assert.equal('string', data.response.commits);
              assert.equal('string', data.response.deletions);
              assert.equal('string', data.response.email);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryContributors', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryFiles - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryFiles('fakedata', 'fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryFiles', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdRepositoryFiles - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryFiles('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdRepositoryFiles', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryFiles - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryFiles('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdRepositoryFiles', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdRepositoryFiles - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryFiles('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdRepositoryFiles', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdRepositoryMergedBranches - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryMergedBranches('fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdRepositoryMergedBranches', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryRawBlobsSha - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryRawBlobsSha('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryRawBlobsSha', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryTags - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryTags('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.commit);
              assert.equal('string', data.response.message);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.release);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryTags', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryTags - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryTags('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.commit);
              assert.equal('string', data.response.message);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.release);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdRepositoryTags', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryTagsTagName - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryTagsTagName('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.commit);
              assert.equal('string', data.response.message);
              assert.equal('string', data.response.name);
              assert.equal('object', typeof data.response.release);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryTagsTagName', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdRepositoryTagsTagName - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryTagsTagName('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdRepositoryTagsTagName', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdRepositoryTagsTagNameRelease - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryTagsTagNameRelease('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.tag_name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdRepositoryTagsTagNameRelease', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryTagsTagNameRelease - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryTagsTagNameRelease('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.tag_name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdRepositoryTagsTagNameRelease', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryTree - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryTree('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.mode);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.type);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRepositoryTree', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRunners - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRunners('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.active);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.is_shared);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdRunners', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRunners - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRunners('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.active);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.is_shared);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdRunners', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdRunnersRunnerId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRunnersRunnerId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.active);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.is_shared);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdRunnersRunnerId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesAsana - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesAsana('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesAsana', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesAssembla - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesAssembla('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesAssembla', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesBamboo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesBamboo('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesBamboo', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesBugzilla - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesBugzilla('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesBugzilla', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesBuildkite - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesBuildkite('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesBuildkite', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesBuildsEmail - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesBuildsEmail('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesBuildsEmail', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesCampfire - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesCampfire('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesCampfire', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesCustomIssueTracker - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesCustomIssueTracker('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesCustomIssueTracker', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesDroneCi - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesDroneCi('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesDroneCi', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesEmailsOnPush - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesEmailsOnPush('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesEmailsOnPush', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesExternalWiki - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesExternalWiki('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesExternalWiki', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesFlowdock - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesFlowdock('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesFlowdock', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesGemnasium - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesGemnasium('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesGemnasium', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesHipchat - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesHipchat('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesHipchat', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesIrker - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesIrker('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesIrker', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesJira - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesJira('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesJira', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesKubernetes - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesKubernetes('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesKubernetes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesMattermost - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesMattermost('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesMattermost', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesMattermostSlashCommands - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesMattermostSlashCommands('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesMattermostSlashCommands', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdServicesMattermostSlashCommandsTrigger - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdServicesMattermostSlashCommandsTrigger('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdServicesMattermostSlashCommandsTrigger', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesPipelinesEmail - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesPipelinesEmail('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesPipelinesEmail', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesPivotaltracker - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesPivotaltracker('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesPivotaltracker', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesPushover - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesPushover('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesPushover', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesRedmine - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesRedmine('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesRedmine', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesSlack - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesSlack('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesSlack', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesSlackSlashCommands - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesSlackSlashCommands('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesSlackSlashCommands', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdServicesSlackSlashCommandsTrigger - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdServicesSlackSlashCommandsTrigger('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdServicesSlackSlashCommandsTrigger', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesTeamcity - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesTeamcity('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdServicesTeamcity', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdServicesServiceSlug - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdServicesServiceSlug('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.active);
              assert.equal('string', data.response.build_events);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_events);
              assert.equal('string', data.response.merge_requests_events);
              assert.equal('string', data.response.note_events);
              assert.equal('string', data.response.pipeline_events);
              assert.equal('string', data.response.properties);
              assert.equal('string', data.response.push_events);
              assert.equal('string', data.response.tag_push_events);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdServicesServiceSlug', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdServicesServiceSlug - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdServicesServiceSlug('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdServicesServiceSlug', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdShare - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdShare('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.group_access);
              assert.equal('string', data.response.group_id);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.project_id);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdShare', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdShareGroupId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdShareGroupId('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdShareGroupId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippets('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.file_name);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdSnippets', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdSnippets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippets('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.file_name);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdSnippets', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsNoteableIdNotes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsNoteableIdNotes('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdSnippetsNoteableIdNotes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdSnippetsNoteableIdNotes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsNoteableIdNotes('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdSnippetsNoteableIdNotes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsNoteableIdNotesNoteId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsNoteableIdNotesNoteId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdSnippetsNoteableIdNotesNoteId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdSnippetsNoteableIdNotesNoteId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdSnippetsNoteableIdNotesNoteId('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdSnippetsNoteableIdNotesNoteId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdSnippetsNoteableIdNotesNoteId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsNoteableIdNotesNoteId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.attachment);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response['downvote?']);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.noteable_id);
              assert.equal('string', data.response.noteable_type);
              assert.equal('string', data.response.system);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response['upvote?']);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdSnippetsNoteableIdNotesNoteId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsSnippetId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.file_name);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdSnippetsSnippetId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdSnippetsSnippetId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdSnippetsSnippetId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.expires_at);
              assert.equal('string', data.response.file_name);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdSnippetsSnippetId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdSnippetsSnippetId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsSnippetId('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdSnippetsSnippetId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsSnippetIdAwardEmoji - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdAwardEmoji('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdSnippetsSnippetIdAwardEmoji', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdSnippetsSnippetIdAwardEmoji - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsSnippetIdAwardEmoji('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdSnippetsSnippetIdAwardEmoji', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.awardable_id);
              assert.equal('string', data.response.awardable_type);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.updated_at);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsSnippetIdRaw - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdRaw('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdSnippetsSnippetIdRaw', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdStar - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdStar('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.archived);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.builds_enabled);
              assert.equal('string', data.response.container_registry_enabled);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.creator_id);
              assert.equal('string', data.response.default_branch);
              assert.equal('string', data.response.description);
              assert.equal('object', typeof data.response.forked_from_project);
              assert.equal('string', data.response.forks_count);
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_enabled);
              assert.equal('string', data.response.last_activity_at);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.merge_requests_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('object', typeof data.response.namespace);
              assert.equal('string', data.response.only_allow_merge_if_all_discussions_are_resolved);
              assert.equal('string', data.response.only_allow_merge_if_build_succeeds);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('object', typeof data.response.owner);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.public);
              assert.equal('string', data.response.public_builds);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.runners_token);
              assert.equal('string', data.response.shared_runners_enabled);
              assert.equal('string', data.response.shared_with_groups);
              assert.equal('string', data.response.snippets_enabled);
              assert.equal('string', data.response.ssh_url_to_repo);
              assert.equal('string', data.response.star_count);
              assert.equal('object', typeof data.response.statistics);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.wiki_enabled);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdStar', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdStar - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdStar('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.archived);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.builds_enabled);
              assert.equal('string', data.response.container_registry_enabled);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.creator_id);
              assert.equal('string', data.response.default_branch);
              assert.equal('string', data.response.description);
              assert.equal('object', typeof data.response.forked_from_project);
              assert.equal('string', data.response.forks_count);
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_enabled);
              assert.equal('string', data.response.last_activity_at);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.merge_requests_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('object', typeof data.response.namespace);
              assert.equal('string', data.response.only_allow_merge_if_all_discussions_are_resolved);
              assert.equal('string', data.response.only_allow_merge_if_build_succeeds);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('object', typeof data.response.owner);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.public);
              assert.equal('string', data.response.public_builds);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.runners_token);
              assert.equal('string', data.response.shared_runners_enabled);
              assert.equal('string', data.response.shared_with_groups);
              assert.equal('string', data.response.snippets_enabled);
              assert.equal('string', data.response.ssh_url_to_repo);
              assert.equal('string', data.response.star_count);
              assert.equal('object', typeof data.response.statistics);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.wiki_enabled);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdStar', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdStatusesSha - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdStatusesSha('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.allow_failure);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.finished_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.ref);
              assert.equal('string', data.response.sha);
              assert.equal('string', data.response.started_at);
              assert.equal('string', data.response.status);
              assert.equal('string', data.response.target_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdStatusesSha', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdTriggers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdTriggers('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.deleted_at);
              assert.equal('string', data.response.last_used);
              assert.equal('string', data.response.token);
              assert.equal('string', data.response.updated_at);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdTriggers', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdTriggers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdTriggers('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.deleted_at);
              assert.equal('string', data.response.last_used);
              assert.equal('string', data.response.token);
              assert.equal('string', data.response.updated_at);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdTriggers', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdTriggersToken - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdTriggersToken('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.deleted_at);
              assert.equal('string', data.response.last_used);
              assert.equal('string', data.response.token);
              assert.equal('string', data.response.updated_at);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdTriggersToken', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdTriggersToken - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdTriggersToken('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.deleted_at);
              assert.equal('string', data.response.last_used);
              assert.equal('string', data.response.token);
              assert.equal('string', data.response.updated_at);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdTriggersToken', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdUnarchive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdUnarchive('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.archived);
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.builds_enabled);
              assert.equal('string', data.response.container_registry_enabled);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.creator_id);
              assert.equal('string', data.response.default_branch);
              assert.equal('string', data.response.description);
              assert.equal('object', typeof data.response.forked_from_project);
              assert.equal('string', data.response.forks_count);
              assert.equal('string', data.response.http_url_to_repo);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.issues_enabled);
              assert.equal('string', data.response.last_activity_at);
              assert.equal('string', data.response.lfs_enabled);
              assert.equal('string', data.response.merge_requests_enabled);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.name_with_namespace);
              assert.equal('object', typeof data.response.namespace);
              assert.equal('string', data.response.only_allow_merge_if_all_discussions_are_resolved);
              assert.equal('string', data.response.only_allow_merge_if_build_succeeds);
              assert.equal('string', data.response.open_issues_count);
              assert.equal('object', typeof data.response.owner);
              assert.equal('string', data.response.path);
              assert.equal('string', data.response.path_with_namespace);
              assert.equal('string', data.response.public);
              assert.equal('string', data.response.public_builds);
              assert.equal('string', data.response.request_access_enabled);
              assert.equal('string', data.response.runners_token);
              assert.equal('string', data.response.shared_runners_enabled);
              assert.equal('string', data.response.shared_with_groups);
              assert.equal('string', data.response.snippets_enabled);
              assert.equal('string', data.response.ssh_url_to_repo);
              assert.equal('string', data.response.star_count);
              assert.equal('object', typeof data.response.statistics);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.visibility_level);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.wiki_enabled);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdUnarchive', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdUploads - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdUploads('fakedata', 'fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdUploads', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdUsers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdUsers('fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdUsers', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdVariables - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdVariables('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.value);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdVariables', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdVariables - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdVariables('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.value);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'postV3ProjectsIdVariables', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdVariablesKey - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdVariablesKey('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.value);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'getV3ProjectsIdVariablesKey', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdVariablesKey - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdVariablesKey('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.value);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'putV3ProjectsIdVariablesKey', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdVariablesKey - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdVariablesKey('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.value);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('projects', 'deleteV3ProjectsIdVariablesKey', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3InternalAllowed - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3InternalAllowed((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('internal', 'postV3InternalAllowed', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3InternalBroadcastMessage - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3InternalBroadcastMessage((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('internal', 'getV3InternalBroadcastMessage', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3InternalCheck - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3InternalCheck((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('internal', 'getV3InternalCheck', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3InternalDiscover - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3InternalDiscover((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('internal', 'getV3InternalDiscover', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3InternalLfsAuthenticate - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3InternalLfsAuthenticate((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('internal', 'postV3InternalLfsAuthenticate', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3InternalMergeRequestUrls - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3InternalMergeRequestUrls((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('internal', 'getV3InternalMergeRequestUrls', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3InternalTwoFactorRecoveryCodes - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3InternalTwoFactorRecoveryCodes((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('internal', 'postV3InternalTwoFactorRecoveryCodes', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Issues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Issues('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.assignee);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.confidential);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.downvotes);
              assert.equal('string', data.response.due_date);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.iid);
              assert.equal('string', data.response.labels);
              assert.equal('object', typeof data.response.milestone);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.subscribed);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.upvotes);
              assert.equal('string', data.response.user_notes_count);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('issues', 'getV3Issues', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3KeysId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3KeysId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
              assert.equal('object', typeof data.response.user);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('keys', 'getV3KeysId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3CiLint - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.postV3CiLint('fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('ci', 'postV3CiLint', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Namespaces - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Namespaces('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.kind);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.path);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('namespaces', 'getV3Namespaces', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3NotificationSettings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3NotificationSettings((data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.events);
              assert.equal('string', data.response.level);
              assert.equal('string', data.response.notification_email);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('notification_settings', 'getV3NotificationSettings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3NotificationSettings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3NotificationSettings('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.events);
              assert.equal('string', data.response.level);
              assert.equal('string', data.response.notification_email);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('notification_settings', 'putV3NotificationSettings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Runners - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Runners('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.active);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.is_shared);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('runners', 'getV3Runners', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3RunnersAll - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3RunnersAll('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.active);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.is_shared);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('runners', 'getV3RunnersAll', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3RunnersId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3RunnersId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.active);
              assert.equal('string', data.response.architecture);
              assert.equal('string', data.response.contacted_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.is_shared);
              assert.equal('string', data.response.locked);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.platform);
              assert.equal('object', typeof data.response.projects);
              assert.equal('string', data.response.revision);
              assert.equal('string', data.response.run_untagged);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.token);
              assert.equal('string', data.response.version);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('runners', 'getV3RunnersId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3RunnersId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3RunnersId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.active);
              assert.equal('string', data.response.architecture);
              assert.equal('string', data.response.contacted_at);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.is_shared);
              assert.equal('string', data.response.locked);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.platform);
              assert.equal('object', typeof data.response.projects);
              assert.equal('string', data.response.revision);
              assert.equal('string', data.response.run_untagged);
              assert.equal('string', data.response.tag_list);
              assert.equal('string', data.response.token);
              assert.equal('string', data.response.version);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('runners', 'putV3RunnersId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3RunnersId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3RunnersId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.active);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.is_shared);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('runners', 'deleteV3RunnersId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Snippets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Snippets('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.file_name);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.raw_url);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('snippets', 'getV3Snippets', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3Snippets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3Snippets('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.file_name);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.raw_url);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('snippets', 'postV3Snippets', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3SnippetsPublic - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3SnippetsPublic('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.file_name);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.raw_url);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('snippets', 'getV3SnippetsPublic', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3SnippetsId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3SnippetsId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.file_name);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.raw_url);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('snippets', 'getV3SnippetsId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3SnippetsId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3SnippetsId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.file_name);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.raw_url);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('snippets', 'putV3SnippetsId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3SnippetsId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3SnippetsId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.file_name);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.raw_url);
              assert.equal('string', data.response.title);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('snippets', 'deleteV3SnippetsId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3SnippetsIdRaw - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3SnippetsIdRaw('fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('snippets', 'getV3SnippetsIdRaw', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Hooks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Hooks((data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.enable_ssl_verification);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.push_events);
              assert.equal('string', data.response.tag_push_events);
              assert.equal('string', data.response.url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('hooks', 'getV3Hooks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3Hooks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3Hooks('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.enable_ssl_verification);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.push_events);
              assert.equal('string', data.response.tag_push_events);
              assert.equal('string', data.response.url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('hooks', 'postV3Hooks', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3HooksId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3HooksId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.enable_ssl_verification);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.push_events);
              assert.equal('string', data.response.tag_push_events);
              assert.equal('string', data.response.url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('hooks', 'getV3HooksId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3HooksId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3HooksId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.enable_ssl_verification);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.push_events);
              assert.equal('string', data.response.tag_push_events);
              assert.equal('string', data.response.url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('hooks', 'deleteV3HooksId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Todos - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Todos('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.action_name);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.project);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.target);
              assert.equal('string', data.response.target_type);
              assert.equal('string', data.response.target_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('todos', 'getV3Todos', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3Todos - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3Todos((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('todos', 'deleteV3Todos', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3TodosId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3TodosId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.action_name);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.body);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.project);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.target);
              assert.equal('string', data.response.target_type);
              assert.equal('string', data.response.target_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('todos', 'deleteV3TodosId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Users - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Users('fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'getV3Users', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3Users - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3Users('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.bio);
              assert.equal('string', data.response.can_create_group);
              assert.equal('string', data.response.can_create_project);
              assert.equal('string', data.response.color_scheme_id);
              assert.equal('string', data.response.confirmed_at);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.current_sign_in_at);
              assert.equal('string', data.response.email);
              assert.equal('string', data.response.external);
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.identities);
              assert.equal('string', data.response.is_admin);
              assert.equal('string', data.response.last_sign_in_at);
              assert.equal('string', data.response.linkedin);
              assert.equal('string', data.response.location);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.organization);
              assert.equal('string', data.response.projects_limit);
              assert.equal('string', data.response.skype);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.theme_id);
              assert.equal('string', data.response.twitter);
              assert.equal('string', data.response.two_factor_enabled);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.website_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'postV3Users', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UsersId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UsersId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'getV3UsersId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3UsersId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3UsersId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.bio);
              assert.equal('string', data.response.can_create_group);
              assert.equal('string', data.response.can_create_project);
              assert.equal('string', data.response.color_scheme_id);
              assert.equal('string', data.response.confirmed_at);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.current_sign_in_at);
              assert.equal('string', data.response.email);
              assert.equal('string', data.response.external);
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.identities);
              assert.equal('string', data.response.is_admin);
              assert.equal('string', data.response.last_sign_in_at);
              assert.equal('string', data.response.linkedin);
              assert.equal('string', data.response.location);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.organization);
              assert.equal('string', data.response.projects_limit);
              assert.equal('string', data.response.skype);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.theme_id);
              assert.equal('string', data.response.twitter);
              assert.equal('string', data.response.two_factor_enabled);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.website_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'putV3UsersId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3UsersId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3UsersId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.email);
              assert.equal('string', data.response.id);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'deleteV3UsersId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3UsersIdBlock - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3UsersIdBlock('fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'putV3UsersIdBlock', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UsersIdEmails - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UsersIdEmails('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.email);
              assert.equal('string', data.response.id);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'getV3UsersIdEmails', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3UsersIdEmails - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3UsersIdEmails('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.email);
              assert.equal('string', data.response.id);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'postV3UsersIdEmails', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3UsersIdEmailsEmailId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3UsersIdEmailsEmailId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.email);
              assert.equal('string', data.response.id);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'deleteV3UsersIdEmailsEmailId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UsersIdEvents - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UsersIdEvents('fakedata', 'fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.action_name);
              assert.equal('object', typeof data.response.author);
              assert.equal('string', data.response.author_id);
              assert.equal('string', data.response.author_username);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.data);
              assert.equal('object', typeof data.response.note);
              assert.equal('string', data.response.project_id);
              assert.equal('string', data.response.target_id);
              assert.equal('string', data.response.target_title);
              assert.equal('string', data.response.target_type);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'getV3UsersIdEvents', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UsersIdKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UsersIdKeys('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'getV3UsersIdKeys', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3UsersIdKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3UsersIdKeys('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'postV3UsersIdKeys', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3UsersIdKeysKeyId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3UsersIdKeysKeyId('fakedata', 'fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'deleteV3UsersIdKeysKeyId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3UsersIdUnblock - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.putV3UsersIdUnblock('fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('users', 'putV3UsersIdUnblock', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3User - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3User((data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.bio);
              assert.equal('string', data.response.can_create_group);
              assert.equal('string', data.response.can_create_project);
              assert.equal('string', data.response.color_scheme_id);
              assert.equal('string', data.response.confirmed_at);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.current_sign_in_at);
              assert.equal('string', data.response.email);
              assert.equal('string', data.response.external);
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.identities);
              assert.equal('string', data.response.is_admin);
              assert.equal('string', data.response.last_sign_in_at);
              assert.equal('string', data.response.linkedin);
              assert.equal('string', data.response.location);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.organization);
              assert.equal('string', data.response.projects_limit);
              assert.equal('string', data.response.skype);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.theme_id);
              assert.equal('string', data.response.twitter);
              assert.equal('string', data.response.two_factor_enabled);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.website_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('user', 'getV3User', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UserEmails - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UserEmails((data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.email);
              assert.equal('string', data.response.id);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('user', 'getV3UserEmails', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3UserEmails - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3UserEmails('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.email);
              assert.equal('string', data.response.id);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('user', 'postV3UserEmails', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UserEmailsEmailId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UserEmailsEmailId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.email);
              assert.equal('string', data.response.id);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('user', 'getV3UserEmailsEmailId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3UserEmailsEmailId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3UserEmailsEmailId('fakedata', (data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('user', 'deleteV3UserEmailsEmailId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UserKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UserKeys((data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('user', 'getV3UserKeys', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3UserKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3UserKeys('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('user', 'postV3UserKeys', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UserKeysKeyId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UserKeysKeyId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('user', 'getV3UserKeysKeyId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3UserKeysKeyId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3UserKeysKeyId('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.can_push);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.title);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('user', 'deleteV3UserKeysKeyId', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3DeployKeys - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3DeployKeys((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('deploy_keys', 'getV3DeployKeys', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3Session - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.postV3Session('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.avatar_url);
              assert.equal('string', data.response.bio);
              assert.equal('string', data.response.can_create_group);
              assert.equal('string', data.response.can_create_project);
              assert.equal('string', data.response.color_scheme_id);
              assert.equal('string', data.response.confirmed_at);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.current_sign_in_at);
              assert.equal('string', data.response.email);
              assert.equal('string', data.response.external);
              assert.equal('string', data.response.id);
              assert.equal('object', typeof data.response.identities);
              assert.equal('string', data.response.is_admin);
              assert.equal('string', data.response.last_sign_in_at);
              assert.equal('string', data.response.linkedin);
              assert.equal('string', data.response.location);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.organization);
              assert.equal('string', data.response.private_token);
              assert.equal('string', data.response.projects_limit);
              assert.equal('string', data.response.skype);
              assert.equal('string', data.response.state);
              assert.equal('string', data.response.theme_id);
              assert.equal('string', data.response.twitter);
              assert.equal('string', data.response.two_factor_enabled);
              assert.equal('string', data.response.username);
              assert.equal('string', data.response.web_url);
              assert.equal('string', data.response.website_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('session', 'postV3Session', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ApplicationSettings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ApplicationSettings((data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.after_sign_out_path);
              assert.equal('string', data.response.after_sign_up_text);
              assert.equal('string', data.response.container_registry_token_expire_delay);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.default_branch_protection);
              assert.equal('string', data.response.default_group_visibility);
              assert.equal('string', data.response.default_project_visibility);
              assert.equal('string', data.response.default_projects_limit);
              assert.equal('string', data.response.default_snippet_visibility);
              assert.equal('string', data.response.domain_blacklist);
              assert.equal('string', data.response.domain_blacklist_enabled);
              assert.equal('string', data.response.domain_whitelist);
              assert.equal('string', data.response.gravatar_enabled);
              assert.equal('string', data.response.home_page_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.koding_enabled);
              assert.equal('string', data.response.koding_url);
              assert.equal('string', data.response.max_attachment_size);
              assert.equal('string', data.response.plantuml_enabled);
              assert.equal('string', data.response.plantuml_url);
              assert.equal('string', data.response.repository_storage);
              assert.equal('string', data.response.repository_storages);
              assert.equal('string', data.response.restricted_visibility_levels);
              assert.equal('string', data.response.session_expire_delay);
              assert.equal('string', data.response.sign_in_text);
              assert.equal('string', data.response.signin_enabled);
              assert.equal('string', data.response.signup_enabled);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.user_oauth_applications);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('application', 'getV3ApplicationSettings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ApplicationSettings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ApplicationSettings('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.after_sign_out_path);
              assert.equal('string', data.response.after_sign_up_text);
              assert.equal('string', data.response.container_registry_token_expire_delay);
              assert.equal('string', data.response.created_at);
              assert.equal('string', data.response.default_branch_protection);
              assert.equal('string', data.response.default_group_visibility);
              assert.equal('string', data.response.default_project_visibility);
              assert.equal('string', data.response.default_projects_limit);
              assert.equal('string', data.response.default_snippet_visibility);
              assert.equal('string', data.response.domain_blacklist);
              assert.equal('string', data.response.domain_blacklist_enabled);
              assert.equal('string', data.response.domain_whitelist);
              assert.equal('string', data.response.gravatar_enabled);
              assert.equal('string', data.response.home_page_url);
              assert.equal('string', data.response.id);
              assert.equal('string', data.response.koding_enabled);
              assert.equal('string', data.response.koding_url);
              assert.equal('string', data.response.max_attachment_size);
              assert.equal('string', data.response.plantuml_enabled);
              assert.equal('string', data.response.plantuml_url);
              assert.equal('string', data.response.repository_storage);
              assert.equal('string', data.response.repository_storages);
              assert.equal('string', data.response.restricted_visibility_levels);
              assert.equal('string', data.response.session_expire_delay);
              assert.equal('string', data.response.sign_in_text);
              assert.equal('string', data.response.signin_enabled);
              assert.equal('string', data.response.signup_enabled);
              assert.equal('string', data.response.updated_at);
              assert.equal('string', data.response.user_oauth_applications);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('application', 'putV3ApplicationSettings', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3SidekiqCompoundMetrics - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3SidekiqCompoundMetrics((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('sidekiq', 'getV3SidekiqCompoundMetrics', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3SidekiqJobStats - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3SidekiqJobStats((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('sidekiq', 'getV3SidekiqJobStats', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3SidekiqProcessMetrics - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3SidekiqProcessMetrics((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('sidekiq', 'getV3SidekiqProcessMetrics', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3SidekiqQueueMetrics - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3SidekiqQueueMetrics((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('sidekiq', 'getV3SidekiqQueueMetrics', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Licenses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Licenses('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.conditions);
              assert.equal('string', data.response.content);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.html_url);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.limitations);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.nickname);
              assert.equal('string', data.response.permissions);
              assert.equal('string', data.response.popular);
              assert.equal('string', data.response.source_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('licenses', 'getV3Licenses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3LicensesName - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3LicensesName('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.conditions);
              assert.equal('string', data.response.content);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.html_url);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.limitations);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.nickname);
              assert.equal('string', data.response.permissions);
              assert.equal('string', data.response.popular);
              assert.equal('string', data.response.source_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('licenses', 'getV3LicensesName', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesDockerfiles - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3TemplatesDockerfiles((data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('templates', 'getV3TemplatesDockerfiles', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesDockerfilesName - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3TemplatesDockerfilesName('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.content);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('templates', 'getV3TemplatesDockerfilesName', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesGitignores - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3TemplatesGitignores((data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('templates', 'getV3TemplatesGitignores', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesGitignoresName - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3TemplatesGitignoresName('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.content);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('templates', 'getV3TemplatesGitignoresName', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesGitlabCiYmls - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3TemplatesGitlabCiYmls((data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('templates', 'getV3TemplatesGitlabCiYmls', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesGitlabCiYmlsName - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3TemplatesGitlabCiYmlsName('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.content);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('templates', 'getV3TemplatesGitlabCiYmlsName', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesLicenses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3TemplatesLicenses('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.conditions);
              assert.equal('string', data.response.content);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.html_url);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.limitations);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.nickname);
              assert.equal('string', data.response.permissions);
              assert.equal('string', data.response.popular);
              assert.equal('string', data.response.source_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('templates', 'getV3TemplatesLicenses', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesLicensesName - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3TemplatesLicensesName('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.conditions);
              assert.equal('string', data.response.content);
              assert.equal('string', data.response.description);
              assert.equal('string', data.response.html_url);
              assert.equal('string', data.response.key);
              assert.equal('string', data.response.limitations);
              assert.equal('string', data.response.name);
              assert.equal('string', data.response.nickname);
              assert.equal('string', data.response.permissions);
              assert.equal('string', data.response.popular);
              assert.equal('string', data.response.source_url);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('templates', 'getV3TemplatesLicensesName', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Gitignores - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Gitignores((data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('gitignores', 'getV3Gitignores', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GitignoresName - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GitignoresName('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.content);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('gitignores', 'getV3GitignoresName', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GitlabCiYmls - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GitlabCiYmls((data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('gitlab_ci_ymls', 'getV3GitlabCiYmls', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GitlabCiYmlsName - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GitlabCiYmlsName('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.content);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('gitlab_ci_ymls', 'getV3GitlabCiYmlsName', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Dockerfiles - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Dockerfiles((data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('dockerfiles', 'getV3Dockerfiles', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3DockerfilesName - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        const p = new Promise((resolve) => {
          a.getV3DockerfilesName('fakedata', (data, error) => {
            runCommonAsserts(data, error);

            if (stub) {
              assert.equal('string', data.response.content);
              assert.equal('string', data.response.name);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('dockerfiles', 'getV3DockerfilesName', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Version - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        const p = new Promise((resolve) => {
          a.getV3Version((data, error) => {
            if (stub) {
              const displayE = 'Error 400 received on request';
              runErrorAsserts(data, error, 'AD.500', 'Test-gitlab-connectorRest-handleEndResponse', displayE);
            } else {
              runCommonAsserts(data, error);
            }

            saveMockData('version', 'getV3Version', 'default', data);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });
  });
});
