// Set globals
/* global describe it log pronghornProps */
/* eslint global-require:warn */

// include required items for testing & logging
const assert = require('assert');
const fs = require('fs-extra');
const mocha = require('mocha');
const winston = require('winston');
const path = require('path');
const execute = require('child_process').execSync;

// stub and attemptTimeout are used throughout the code so set them here
let logLevel = 'none';
const stub = true;
const isRapidFail = false;
const attemptTimeout = 120000;

// these variables can be changed to run in integrated mode so easier to set them here
// always check these in with bogus data!!!
const host = 'replace.hostorip.here';
const username = 'username';
const password = 'password';
const protocol = 'http';
const port = 80;
const sslenable = false;
const sslinvalid = false;

// these are the adapter properties. You generally should not need to alter
// any of these after they are initially set up
global.pronghornProps = {
  pathProps: {
    encrypted: false
  },
  adapterProps: {
    adapters: [{
      id: 'Test-gitlab',
      type: 'Gitlab',
      properties: {
        host,
        port,
        base_path: '//api',
        version: 'vv3',
        cache_location: 'none',
        protocol,
        stub,
        authentication: {
          auth_method: 'no_authentication',
          username,
          password,
          token: '',
          token_timeout: -1,
          token_cache: 'local',
          invalid_token_error: 401,
          auth_field: 'header.headers.Authorization',
          auth_field_format: 'Basic {b64}{username}:{password}{/b64}'
        },
        healthcheck: {
          type: 'none',
          frequency: 60000
        },
        throttle: {
          throttle_enabled: false,
          number_pronghorns: 1,
          sync_async: 'sync',
          max_in_queue: 1000,
          concurrent_max: 1,
          expire_timeout: 0,
          avg_runtime: 200
        },
        request: {
          number_retries: 3,
          limit_retry_error: 0,
          failover_codes: [],
          attempt_timeout: attemptTimeout,
          healthcheck_on_timeout: true,
          archiving: false
        },
        proxy: {
          enabled: false,
          host: '',
          port: 1,
          protocol: 'http'
        },
        ssl: {
          ecdhCurve: '',
          enabled: sslenable,
          accept_invalid_cert: sslinvalid,
          ca_file: '',
          secure_protocol: '',
          ciphers: ''
        }
      }
    }]
  }
};

global.$HOME = `${__dirname}/../..`;

// set the log levels that Pronghorn uses, spam and trace are not defaulted in so without
// this you may error on log.trace calls.
const myCustomLevels = {
  levels: {
    spam: 6,
    trace: 5,
    debug: 4,
    info: 3,
    warn: 2,
    error: 1,
    none: 0
  }
};

// need to see if there is a log level passed in
process.argv.forEach((val) => {
  // is there a log level defined to be passed in?
  if (val.indexOf('--LOG') === 0) {
    // get the desired log level
    const inputVal = val.split('=')[1];

    // validate the log level is supported, if so set it
    if (Object.hasOwnProperty.call(myCustomLevels.levels, inputVal)) {
      logLevel = inputVal;
    }
  }
});

// need to set global logging
global.log = new (winston.Logger)({
  level: logLevel,
  levels: myCustomLevels.levels,
  transports: [
    new winston.transports.Console()
  ]
});

/**
 * Runs the error asserts for the test
 */
function runErrorAsserts(data, error, code, origin, displayStr) {
  assert.equal(null, data);
  assert.notEqual(undefined, error);
  assert.notEqual(null, error);
  assert.notEqual(undefined, error.IAPerror);
  assert.notEqual(null, error.IAPerror);
  assert.notEqual(undefined, error.IAPerror.displayString);
  assert.notEqual(null, error.IAPerror.displayString);
  assert.equal(code, error.icode);
  assert.equal(origin, error.IAPerror.origin);
  assert.equal(displayStr, error.IAPerror.displayString);
}


// require the adapter that we are going to be using
const Gitlab = require('../../adapter.js');

// delete the .DS_Store directory in entities -- otherwise this will cause errors
const dirPath = path.join(__dirname, '../../entities/.DS_Store');
if (fs.existsSync(dirPath)) {
  try {
    fs.removeSync(dirPath);
    console.log('.DS_Store deleted');
  } catch (e) {
    console.log('Error when deleting .DS_Store:', e);
  }
}

// begin the testing - these should be pretty well defined between the describe and the it!
describe('[unit] Gitlab Adapter Test', () => {
  describe('Gitlab Class Tests', () => {
    const a = new Gitlab(
      pronghornProps.adapterProps.adapters[0].id,
      pronghornProps.adapterProps.adapters[0].properties
    );

    if (isRapidFail) {
      const state = {};
      state.passed = true;

      mocha.afterEach(function x() {
        state.passed = state.passed
        && (this.currentTest.state === 'passed');
      });
      mocha.beforeEach(function x() {
        if (!state.passed) {
          return this.currentTest.skip();
        }
        return true;
      });
    }

    describe('#class instance created', () => {
      it('should be a class with properties', (done) => {
        assert.notEqual(null, a);
        assert.notEqual(undefined, a);
        assert.notEqual(null, a.allProps);
        const check = global.pronghornProps.adapterProps.adapters[0].properties.healthcheck.type;
        assert.equal(check, a.healthcheckType);
        done();
      }).timeout(attemptTimeout);
    });

    describe('adapterBase.js', () => {
      it('should have an adapterBase.js', (done) => {
        fs.exists('adapterBase.js', (val) => {
          assert.equal(true, val);
          done();
        });
      });
    });

    let wffunctions = [];
    describe('#getWorkflowFunctions', () => {
      it('should retrieve workflow functions', (done) => {
        const p = new Promise((resolve) => {
          wffunctions = a.getWorkflowFunctions();
          assert.notEqual(0, wffunctions.length);
          resolve();
          done();
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('package.json', () => {
      it('should have a package.json', (done) => {
        fs.exists('package.json', (val) => {
          assert.equal(true, val);
          done();
        });
      });
      it('package.json should be customized', (done) => {
        const packageDotJson = require('../../package.json');
        assert.notEqual(-1, packageDotJson.name.indexOf('gitlab'));
        assert.notEqual(undefined, packageDotJson.version);
        assert.notEqual(null, packageDotJson.version);
        assert.notEqual('', packageDotJson.version);
        done();
      });
    });

    describe('pronghorn.json', () => {
      it('should have a pronghorn.json', (done) => {
        fs.exists('pronghorn.json', (val) => {
          assert.equal(true, val);
          done();
        });
      });
      it('pronghorn.json should be customized', (done) => {
        const pronghornDotJson = require('../../pronghorn.json');
        assert.notEqual(-1, pronghornDotJson.id.indexOf('gitlab'));
        assert.equal('Gitlab', pronghornDotJson.export);
        assert.equal('Gitlab', pronghornDotJson.displayName);
        assert.equal('Gitlab', pronghornDotJson.title);
        done();
      });
      it('pronghorn.json should only expose workflow functions', (done) => {
        const pronghornDotJson = require('../../pronghorn.json');

        for (let m = 0; m < pronghornDotJson.methods.length; m += 1) {
          let found = false;
          let paramissue = false;

          for (let w = 0; w < wffunctions.length; w += 1) {
            if (pronghornDotJson.methods[m].name === wffunctions[w]) {
              found = true;
              const methLine = execute(`grep "${wffunctions[w]}(" adapter.js | grep "callback) {"`).toString();
              let wfparams = [];

              if (methLine.indexOf('(') >= 0 && methLine.indexOf(')') >= 0) {
                const temp = methLine.substring(methLine.indexOf('(') + 1, methLine.indexOf(')'));
                wfparams = temp.split(',');

                for (let t = 0; t < wfparams.length; t += 1) {
                  // remove default value from the parameter name
                  wfparams[t] = wfparams[t].substring(0, wfparams[t].search(/=/) > 0 ? wfparams[t].search(/#|\?|=/) : wfparams[t].length);
                  // remove spaces
                  wfparams[t] = wfparams[t].trim();

                  if (wfparams[t] === 'callback') {
                    wfparams.splice(t, 1);
                  }
                }
              }

              // if there are inputs defined but not on the method line
              if (wfparams.length === 0 && (pronghornDotJson.methods[m].input
                  && pronghornDotJson.methods[m].input.length > 0)) {
                paramissue = true;
              } else if (wfparams.length > 0 && (!pronghornDotJson.methods[m].input
                  || pronghornDotJson.methods[m].input.length === 0)) {
                // if there are no inputs defined but there are on the method line
                paramissue = true;
              } else {
                for (let p = 0; p < pronghornDotJson.methods[m].input.length; p += 1) {
                  let pfound = false;
                  for (let wfp = 0; wfp < wfparams.length; wfp += 1) {
                    if (pronghornDotJson.methods[m].input[p].name === wfparams[wfp]) {
                      pfound = true;
                    }
                  }

                  if (!pfound) {
                    paramissue = true;
                  }
                }
                for (let wfp = 0; wfp < wfparams.length; wfp += 1) {
                  let pfound = false;
                  for (let p = 0; p < pronghornDotJson.methods[m].input.length; p += 1) {
                    if (pronghornDotJson.methods[m].input[p].name === wfparams[wfp]) {
                      pfound = true;
                    }
                  }

                  if (!pfound) {
                    paramissue = true;
                  }
                }
              }

              break;
            }
          }

          if (!found) {
            // this is the reason to go through both loops - log which ones are not found so
            // they can be worked
            log.error(`${pronghornDotJson.methods[m].name} not found in workflow functions`);
          }
          if (paramissue) {
            // this is the reason to go through both loops - log which ones are not found so
            // they can be worked
            log.error(`${pronghornDotJson.methods[m].name} has a parameter mismatch`);
          }
          assert.equal(true, found);
          assert.equal(false, paramissue);
        }
        done();
      }).timeout(attemptTimeout);
      it('pronghorn.json should expose all workflow functions', (done) => {
        const pronghornDotJson = require('../../pronghorn.json');
        for (let w = 0; w < wffunctions.length; w += 1) {
          let found = false;

          for (let m = 0; m < pronghornDotJson.methods.length; m += 1) {
            if (pronghornDotJson.methods[m].name === wffunctions[w]) {
              found = true;
              break;
            }
          }

          if (!found) {
            // this is the reason to go through both loops - log which ones are not found so
            // they can be worked
            log.error(`${wffunctions[w]} not found in pronghorn.json`);
          }
          assert.equal(true, found);
        }
        done();
      });
    });

    describe('propertiesSchema.json', () => {
      it('should have a propertiesSchema.json', (done) => {
        fs.exists('propertiesSchema.json', (val) => {
          assert.equal(true, val);
          done();
        });
      });
      it('propertiesSchema.json should be customized', (done) => {
        const propertiesDotJson = require('../../propertiesSchema.json');
        assert.equal('adapter-gitlab', propertiesDotJson.$id);
        done();
      });
    });

    describe('error.json', () => {
      it('should have an error.json', (done) => {
        fs.exists('error.json', (val) => {
          assert.equal(true, val);
          done();
        });
      });
    });

    describe('README.md', () => {
      it('should have a README', (done) => {
        fs.exists('README.md', (val) => {
          assert.equal(true, val);
          done();
        });
      });
      it('README.md should be customized', (done) => {
        fs.readFile('README.md', 'utf8', (err, data) => {
          assert.equal(-1, data.indexOf('[System]'));
          assert.equal(-1, data.indexOf('[system]'));
          assert.equal(-1, data.indexOf('[version]'));
          assert.equal(-1, data.indexOf('[namespace]'));
          done();
        });
      });
    });

    describe('#connect', () => {
      it('should have a connect function', (done) => {
        assert.equal(true, typeof a.connect === 'function');
        done();
      });
    });

    describe('#healthCheck', () => {
      it('should have a healthCheck function', (done) => {
        assert.equal(true, typeof a.healthCheck === 'function');
        done();
      });
    });

    describe('#checkActionFiles', () => {
      it('should have a checkActionFiles function', (done) => {
        assert.equal(true, typeof a.checkActionFiles === 'function');
        done();
      });
      it('should be good', (done) => {
        const clean = a.checkActionFiles();
        assert.equal(true, clean);
        done();
      }).timeout(attemptTimeout);
    });

    describe('#encryptProperty', () => {
      it('should have a encryptProperty function', (done) => {
        assert.equal(true, typeof a.encryptProperty === 'function');
        done();
      });
      it('should get base64 encoded property', (done) => {
        const p = new Promise((resolve) => {
          a.encryptProperty('testing', 'base64', (data, error) => {
            assert.equal(undefined, error);
            assert.notEqual(undefined, data);
            assert.notEqual(null, data);
            assert.notEqual(undefined, data.response);
            assert.notEqual(null, data.response);
            assert.equal(0, data.response.indexOf('{code}'));
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should get encrypted property', (done) => {
        const p = new Promise((resolve) => {
          a.encryptProperty('testing', 'encrypt', (data, error) => {
            assert.equal(undefined, error);
            assert.notEqual(undefined, data);
            assert.notEqual(null, data);
            assert.notEqual(undefined, data.response);
            assert.notEqual(null, data.response);
            assert.equal(0, data.response.indexOf('{crypt}'));
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    // describe('#hasEntity', () => {
    //   it('should have a hasEntity function', (done) => {
    //     assert.equal(true, typeof a.hasEntity === 'function');
    //     done();
    //   });
    //   it('should find entity', (done) => {
    //     const p = new Promise((resolve) => {
    //       a.hasEntity('template_entity', // 'a9e9c33dc61122760072455df62663d2', (data) => {
    //         assert.equal(true, data[0]);
    //         resolve(data);
    //         done();
    //       });
    //     });
    //     // log just done to get rid of const lint issue!
    //     log.debug(p);
    //   }).timeout(attemptTimeout);
    //   it('should not find entity', (done) => {
    //     const p = new Promise((resolve) => {
    //       a.hasEntity('template_entity', 'blah', (data) => {
    //         assert.equal(false, data[0]);
    //         resolve(data);
    //         done();
    //       });
    //     });
    //     // log just done to get rid of const lint issue!
    //     log.debug(p);
    //   }).timeout(attemptTimeout);
    // });

    /*
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    *** All code above this comment will be replaced during a migration ***
    ******************* DO NOT REMOVE THIS COMMENT BLOCK ******************
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    */

    describe('#getV3Groups - errors', () => {
      it('should have a getV3Groups function', (done) => {
        assert.equal(true, typeof a.getV3Groups === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#postV3Groups - errors', () => {
      it('should have a postV3Groups function', (done) => {
        assert.equal(true, typeof a.postV3Groups === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3Groups(null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3Groups', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsOwned - errors', () => {
      it('should have a getV3GroupsOwned function', (done) => {
        assert.equal(true, typeof a.getV3GroupsOwned === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsId - errors', () => {
      it('should have a getV3GroupsId function', (done) => {
        assert.equal(true, typeof a.getV3GroupsId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3GroupsId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3GroupsId - errors', () => {
      it('should have a putV3GroupsId function', (done) => {
        assert.equal(true, typeof a.putV3GroupsId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3GroupsId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3GroupsId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3GroupsId - errors', () => {
      it('should have a deleteV3GroupsId function', (done) => {
        assert.equal(true, typeof a.deleteV3GroupsId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3GroupsId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3GroupsId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsIdAccessRequests - errors', () => {
      it('should have a getV3GroupsIdAccessRequests function', (done) => {
        assert.equal(true, typeof a.getV3GroupsIdAccessRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdAccessRequests(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3GroupsIdAccessRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3GroupsIdAccessRequests - errors', () => {
      it('should have a postV3GroupsIdAccessRequests function', (done) => {
        assert.equal(true, typeof a.postV3GroupsIdAccessRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3GroupsIdAccessRequests(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3GroupsIdAccessRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3GroupsIdAccessRequestsUserId - errors', () => {
      it('should have a deleteV3GroupsIdAccessRequestsUserId function', (done) => {
        assert.equal(true, typeof a.deleteV3GroupsIdAccessRequestsUserId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3GroupsIdAccessRequestsUserId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3GroupsIdAccessRequestsUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing userId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3GroupsIdAccessRequestsUserId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'userId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3GroupsIdAccessRequestsUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3GroupsIdAccessRequestsUserIdApprove - errors', () => {
      it('should have a putV3GroupsIdAccessRequestsUserIdApprove function', (done) => {
        assert.equal(true, typeof a.putV3GroupsIdAccessRequestsUserIdApprove === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3GroupsIdAccessRequestsUserIdApprove(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3GroupsIdAccessRequestsUserIdApprove', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing userId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3GroupsIdAccessRequestsUserIdApprove('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'userId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3GroupsIdAccessRequestsUserIdApprove', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsIdIssues - errors', () => {
      it('should have a getV3GroupsIdIssues function', (done) => {
        assert.equal(true, typeof a.getV3GroupsIdIssues === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdIssues(null, null, null, null, null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3GroupsIdIssues', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsIdMembers - errors', () => {
      it('should have a getV3GroupsIdMembers function', (done) => {
        assert.equal(true, typeof a.getV3GroupsIdMembers === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdMembers(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3GroupsIdMembers', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3GroupsIdMembers - errors', () => {
      it('should have a postV3GroupsIdMembers function', (done) => {
        assert.equal(true, typeof a.postV3GroupsIdMembers === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3GroupsIdMembers(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3GroupsIdMembers', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3GroupsIdMembers('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3GroupsIdMembers', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsIdMembersUserId - errors', () => {
      it('should have a getV3GroupsIdMembersUserId function', (done) => {
        assert.equal(true, typeof a.getV3GroupsIdMembersUserId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdMembersUserId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3GroupsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing userId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdMembersUserId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'userId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3GroupsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3GroupsIdMembersUserId - errors', () => {
      it('should have a putV3GroupsIdMembersUserId function', (done) => {
        assert.equal(true, typeof a.putV3GroupsIdMembersUserId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3GroupsIdMembersUserId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3GroupsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing userId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3GroupsIdMembersUserId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'userId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3GroupsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3GroupsIdMembersUserId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3GroupsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3GroupsIdMembersUserId - errors', () => {
      it('should have a deleteV3GroupsIdMembersUserId function', (done) => {
        assert.equal(true, typeof a.deleteV3GroupsIdMembersUserId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3GroupsIdMembersUserId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3GroupsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing userId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3GroupsIdMembersUserId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'userId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3GroupsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsIdNotificationSettings - errors', () => {
      it('should have a getV3GroupsIdNotificationSettings function', (done) => {
        assert.equal(true, typeof a.getV3GroupsIdNotificationSettings === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdNotificationSettings(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3GroupsIdNotificationSettings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3GroupsIdNotificationSettings - errors', () => {
      it('should have a putV3GroupsIdNotificationSettings function', (done) => {
        assert.equal(true, typeof a.putV3GroupsIdNotificationSettings === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3GroupsIdNotificationSettings(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3GroupsIdNotificationSettings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GroupsIdProjects - errors', () => {
      it('should have a getV3GroupsIdProjects function', (done) => {
        assert.equal(true, typeof a.getV3GroupsIdProjects === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GroupsIdProjects(null, null, null, null, null, null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3GroupsIdProjects', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3GroupsIdProjectsProjectId - errors', () => {
      it('should have a postV3GroupsIdProjectsProjectId function', (done) => {
        assert.equal(true, typeof a.postV3GroupsIdProjectsProjectId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3GroupsIdProjectsProjectId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3GroupsIdProjectsProjectId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3GroupsIdProjectsProjectId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'projectId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3GroupsIdProjectsProjectId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Projects - errors', () => {
      it('should have a getV3Projects function', (done) => {
        assert.equal(true, typeof a.getV3Projects === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#postV3Projects - errors', () => {
      it('should have a postV3Projects function', (done) => {
        assert.equal(true, typeof a.postV3Projects === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3Projects(null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3Projects', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsAll - errors', () => {
      it('should have a getV3ProjectsAll function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsAll === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsForkId - errors', () => {
      it('should have a postV3ProjectsForkId function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsForkId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsForkId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsForkId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsOwned - errors', () => {
      it('should have a getV3ProjectsOwned function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsOwned === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsSearchQuery - errors', () => {
      it('should have a getV3ProjectsSearchQuery function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsSearchQuery === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing query', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsSearchQuery(null, null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'query is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsSearchQuery', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsStarred - errors', () => {
      it('should have a getV3ProjectsStarred function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsStarred === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsUserUserId - errors', () => {
      it('should have a postV3ProjectsUserUserId function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsUserUserId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing userId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsUserUserId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'userId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsUserUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsUserUserId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsUserUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsVisible - errors', () => {
      it('should have a getV3ProjectsVisible function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsVisible === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsId - errors', () => {
      it('should have a getV3ProjectsId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsId - errors', () => {
      it('should have a putV3ProjectsId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsId - errors', () => {
      it('should have a deleteV3ProjectsId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdAccessRequests - errors', () => {
      it('should have a getV3ProjectsIdAccessRequests function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdAccessRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdAccessRequests(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdAccessRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdAccessRequests - errors', () => {
      it('should have a postV3ProjectsIdAccessRequests function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdAccessRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdAccessRequests(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdAccessRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdAccessRequestsUserId - errors', () => {
      it('should have a deleteV3ProjectsIdAccessRequestsUserId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdAccessRequestsUserId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdAccessRequestsUserId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdAccessRequestsUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing userId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdAccessRequestsUserId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'userId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdAccessRequestsUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdAccessRequestsUserIdApprove - errors', () => {
      it('should have a putV3ProjectsIdAccessRequestsUserIdApprove function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdAccessRequestsUserIdApprove === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdAccessRequestsUserIdApprove(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdAccessRequestsUserIdApprove', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing userId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdAccessRequestsUserIdApprove('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'userId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdAccessRequestsUserIdApprove', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdArchive - errors', () => {
      it('should have a postV3ProjectsIdArchive function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdArchive === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdArchive(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdArchive', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBoards - errors', () => {
      it('should have a getV3ProjectsIdBoards function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdBoards === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBoards(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBoards', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBoardsBoardIdLists - errors', () => {
      it('should have a getV3ProjectsIdBoardsBoardIdLists function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdBoardsBoardIdLists === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBoardsBoardIdLists(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBoardsBoardIdLists', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing boardId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBoardsBoardIdLists('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'boardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBoardsBoardIdLists', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdBoardsBoardIdLists - errors', () => {
      it('should have a postV3ProjectsIdBoardsBoardIdLists function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdBoardsBoardIdLists === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBoardsBoardIdLists(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBoardsBoardIdLists', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing boardId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBoardsBoardIdLists('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'boardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBoardsBoardIdLists', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBoardsBoardIdLists('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBoardsBoardIdLists', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBoardsBoardIdListsListId - errors', () => {
      it('should have a getV3ProjectsIdBoardsBoardIdListsListId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdBoardsBoardIdListsListId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBoardsBoardIdListsListId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBoardsBoardIdListsListId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing boardId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBoardsBoardIdListsListId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'boardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBoardsBoardIdListsListId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing listId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBoardsBoardIdListsListId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'listId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBoardsBoardIdListsListId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdBoardsBoardIdListsListId - errors', () => {
      it('should have a putV3ProjectsIdBoardsBoardIdListsListId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdBoardsBoardIdListsListId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdBoardsBoardIdListsListId(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdBoardsBoardIdListsListId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing boardId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdBoardsBoardIdListsListId('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'boardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdBoardsBoardIdListsListId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing listId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdBoardsBoardIdListsListId('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'listId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdBoardsBoardIdListsListId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdBoardsBoardIdListsListId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdBoardsBoardIdListsListId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdBoardsBoardIdListsListId - errors', () => {
      it('should have a deleteV3ProjectsIdBoardsBoardIdListsListId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdBoardsBoardIdListsListId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdBoardsBoardIdListsListId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdBoardsBoardIdListsListId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing boardId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdBoardsBoardIdListsListId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'boardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdBoardsBoardIdListsListId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing listId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdBoardsBoardIdListsListId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'listId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdBoardsBoardIdListsListId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBuilds - errors', () => {
      it('should have a getV3ProjectsIdBuilds function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdBuilds === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuilds(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBuilds', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBuildsArtifactsRefNameDownload - errors', () => {
      it('should have a getV3ProjectsIdBuildsArtifactsRefNameDownload function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdBuildsArtifactsRefNameDownload === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsArtifactsRefNameDownload(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBuildsArtifactsRefNameDownload', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing refName', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsArtifactsRefNameDownload('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'refName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBuildsArtifactsRefNameDownload', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing job', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsArtifactsRefNameDownload('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'job is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBuildsArtifactsRefNameDownload', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBuildsBuildId - errors', () => {
      it('should have a getV3ProjectsIdBuildsBuildId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdBuildsBuildId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsBuildId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBuildsBuildId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing buildId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsBuildId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'buildId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBuildsBuildId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBuildsBuildIdArtifacts - errors', () => {
      it('should have a getV3ProjectsIdBuildsBuildIdArtifacts function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdBuildsBuildIdArtifacts === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsBuildIdArtifacts(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBuildsBuildIdArtifacts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing buildId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsBuildIdArtifacts('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'buildId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBuildsBuildIdArtifacts', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdBuildsBuildIdArtifactsKeep - errors', () => {
      it('should have a postV3ProjectsIdBuildsBuildIdArtifactsKeep function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdBuildsBuildIdArtifactsKeep === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdArtifactsKeep(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBuildsBuildIdArtifactsKeep', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing buildId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdArtifactsKeep('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'buildId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBuildsBuildIdArtifactsKeep', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdBuildsBuildIdCancel - errors', () => {
      it('should have a postV3ProjectsIdBuildsBuildIdCancel function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdBuildsBuildIdCancel === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdCancel(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBuildsBuildIdCancel', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing buildId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdCancel('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'buildId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBuildsBuildIdCancel', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdBuildsBuildIdErase - errors', () => {
      it('should have a postV3ProjectsIdBuildsBuildIdErase function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdBuildsBuildIdErase === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdErase(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBuildsBuildIdErase', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing buildId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdErase('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'buildId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBuildsBuildIdErase', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdBuildsBuildIdPlay - errors', () => {
      it('should have a postV3ProjectsIdBuildsBuildIdPlay function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdBuildsBuildIdPlay === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdPlay(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBuildsBuildIdPlay', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing buildId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdPlay('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'buildId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBuildsBuildIdPlay', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdBuildsBuildIdRetry - errors', () => {
      it('should have a postV3ProjectsIdBuildsBuildIdRetry function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdBuildsBuildIdRetry === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdRetry(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBuildsBuildIdRetry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing buildId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdBuildsBuildIdRetry('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'buildId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdBuildsBuildIdRetry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdBuildsBuildIdTrace - errors', () => {
      it('should have a getV3ProjectsIdBuildsBuildIdTrace function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdBuildsBuildIdTrace === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsBuildIdTrace(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBuildsBuildIdTrace', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing buildId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdBuildsBuildIdTrace('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'buildId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdBuildsBuildIdTrace', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdDeployKeys - errors', () => {
      it('should have a getV3ProjectsIdDeployKeys function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdDeployKeys === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdDeployKeys(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdDeployKeys', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdDeployKeys - errors', () => {
      it('should have a postV3ProjectsIdDeployKeys function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdDeployKeys === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdDeployKeys(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdDeployKeys', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdDeployKeys('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdDeployKeys', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdDeployKeysKeyId - errors', () => {
      it('should have a getV3ProjectsIdDeployKeysKeyId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdDeployKeysKeyId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdDeployKeysKeyId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdDeployKeysKeyId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdDeployKeysKeyId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'keyId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdDeployKeysKeyId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdDeployKeysKeyId - errors', () => {
      it('should have a deleteV3ProjectsIdDeployKeysKeyId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdDeployKeysKeyId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdDeployKeysKeyId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdDeployKeysKeyId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdDeployKeysKeyId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'keyId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdDeployKeysKeyId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdDeployKeysKeyIdDisable - errors', () => {
      it('should have a deleteV3ProjectsIdDeployKeysKeyIdDisable function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdDeployKeysKeyIdDisable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdDeployKeysKeyIdDisable(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdDeployKeysKeyIdDisable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdDeployKeysKeyIdDisable('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'keyId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdDeployKeysKeyIdDisable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdDeployKeysKeyIdEnable - errors', () => {
      it('should have a postV3ProjectsIdDeployKeysKeyIdEnable function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdDeployKeysKeyIdEnable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdDeployKeysKeyIdEnable(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdDeployKeysKeyIdEnable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdDeployKeysKeyIdEnable('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'keyId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdDeployKeysKeyIdEnable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdDeployments - errors', () => {
      it('should have a getV3ProjectsIdDeployments function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdDeployments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdDeployments(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdDeployments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdDeploymentsDeploymentId - errors', () => {
      it('should have a getV3ProjectsIdDeploymentsDeploymentId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdDeploymentsDeploymentId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdDeploymentsDeploymentId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdDeploymentsDeploymentId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing deploymentId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdDeploymentsDeploymentId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'deploymentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdDeploymentsDeploymentId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdEnvironments - errors', () => {
      it('should have a getV3ProjectsIdEnvironments function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdEnvironments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdEnvironments(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdEnvironments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdEnvironments - errors', () => {
      it('should have a postV3ProjectsIdEnvironments function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdEnvironments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdEnvironments(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdEnvironments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdEnvironments('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdEnvironments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdEnvironmentsEnvironmentId - errors', () => {
      it('should have a putV3ProjectsIdEnvironmentsEnvironmentId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdEnvironmentsEnvironmentId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdEnvironmentsEnvironmentId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdEnvironmentsEnvironmentId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing environmentId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdEnvironmentsEnvironmentId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'environmentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdEnvironmentsEnvironmentId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdEnvironmentsEnvironmentId - errors', () => {
      it('should have a deleteV3ProjectsIdEnvironmentsEnvironmentId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdEnvironmentsEnvironmentId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdEnvironmentsEnvironmentId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdEnvironmentsEnvironmentId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing environmentId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdEnvironmentsEnvironmentId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'environmentId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdEnvironmentsEnvironmentId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdEvents - errors', () => {
      it('should have a getV3ProjectsIdEvents function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdEvents === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdEvents(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdEvents', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdFork - errors', () => {
      it('should have a deleteV3ProjectsIdFork function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdFork === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdFork(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdFork', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdForkForkedFromId - errors', () => {
      it('should have a postV3ProjectsIdForkForkedFromId function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdForkForkedFromId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdForkForkedFromId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdForkForkedFromId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing forkedFromId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdForkForkedFromId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'forkedFromId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdForkForkedFromId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdHooks - errors', () => {
      it('should have a getV3ProjectsIdHooks function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdHooks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdHooks(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdHooks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdHooks - errors', () => {
      it('should have a postV3ProjectsIdHooks function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdHooks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdHooks(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdHooks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdHooks('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdHooks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdHooksHookId - errors', () => {
      it('should have a getV3ProjectsIdHooksHookId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdHooksHookId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdHooksHookId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdHooksHookId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdHooksHookId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'hookId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdHooksHookId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdHooksHookId - errors', () => {
      it('should have a putV3ProjectsIdHooksHookId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdHooksHookId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdHooksHookId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdHooksHookId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdHooksHookId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'hookId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdHooksHookId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdHooksHookId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdHooksHookId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdHooksHookId - errors', () => {
      it('should have a deleteV3ProjectsIdHooksHookId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdHooksHookId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdHooksHookId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdHooksHookId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdHooksHookId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'hookId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdHooksHookId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssues - errors', () => {
      it('should have a getV3ProjectsIdIssues function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdIssues === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssues(null, null, null, null, null, null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssues', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssues - errors', () => {
      it('should have a postV3ProjectsIdIssues function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdIssues === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssues(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssues', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssues('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssues', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesIssueId - errors', () => {
      it('should have a getV3ProjectsIdIssuesIssueId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdIssuesIssueId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdIssuesIssueId - errors', () => {
      it('should have a putV3ProjectsIdIssuesIssueId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdIssuesIssueId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdIssuesIssueId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdIssuesIssueId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdIssuesIssueId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdIssuesIssueId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdIssuesIssueId - errors', () => {
      it('should have a deleteV3ProjectsIdIssuesIssueId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdIssuesIssueId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesIssueId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesIssueId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesIssueId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesIssueId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdAddSpentTime - errors', () => {
      it('should have a postV3ProjectsIdIssuesIssueIdAddSpentTime function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdIssuesIssueIdAddSpentTime === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdAddSpentTime(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdAddSpentTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdAddSpentTime('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdAddSpentTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdAddSpentTime('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdAddSpentTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesIssueIdAwardEmoji - errors', () => {
      it('should have a getV3ProjectsIdIssuesIssueIdAwardEmoji function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdIssuesIssueIdAwardEmoji === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdAwardEmoji(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdAwardEmoji('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdAwardEmoji - errors', () => {
      it('should have a postV3ProjectsIdIssuesIssueIdAwardEmoji function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdIssuesIssueIdAwardEmoji === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdAwardEmoji(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdAwardEmoji('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdAwardEmoji('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesIssueIdAwardEmojiAwardId - errors', () => {
      it('should have a getV3ProjectsIdIssuesIssueIdAwardEmojiAwardId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdIssuesIssueIdAwardEmojiAwardId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing awardId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdAwardEmojiAwardId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'awardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdAwardEmojiAwardId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdAwardEmojiAwardId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdIssuesIssueIdAwardEmojiAwardId - errors', () => {
      it('should have a deleteV3ProjectsIdIssuesIssueIdAwardEmojiAwardId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdIssuesIssueIdAwardEmojiAwardId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing awardId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesIssueIdAwardEmojiAwardId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'awardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesIssueIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesIssueIdAwardEmojiAwardId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesIssueIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesIssueIdAwardEmojiAwardId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesIssueIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdMove - errors', () => {
      it('should have a postV3ProjectsIdIssuesIssueIdMove function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdIssuesIssueIdMove === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdMove(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdMove', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdMove('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdMove', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdMove('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdMove', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji - errors', () => {
      it('should have a getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji - errors', () => {
      it('should have a postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId - errors', () => {
      it('should have a getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing awardId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'awardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId - errors', () => {
      it('should have a deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing awardId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'awardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesIssueIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdResetSpentTime - errors', () => {
      it('should have a postV3ProjectsIdIssuesIssueIdResetSpentTime function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdIssuesIssueIdResetSpentTime === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdResetSpentTime(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdResetSpentTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdResetSpentTime('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdResetSpentTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdResetTimeEstimate - errors', () => {
      it('should have a postV3ProjectsIdIssuesIssueIdResetTimeEstimate function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdIssuesIssueIdResetTimeEstimate === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdResetTimeEstimate(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdResetTimeEstimate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdResetTimeEstimate('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdResetTimeEstimate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdTimeEstimate - errors', () => {
      it('should have a postV3ProjectsIdIssuesIssueIdTimeEstimate function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdIssuesIssueIdTimeEstimate === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdTimeEstimate(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdTimeEstimate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdTimeEstimate('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdTimeEstimate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdTimeEstimate('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdTimeEstimate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesIssueIdTimeStats - errors', () => {
      it('should have a getV3ProjectsIdIssuesIssueIdTimeStats function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdIssuesIssueIdTimeStats === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdTimeStats(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdTimeStats', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesIssueIdTimeStats('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesIssueIdTimeStats', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesIssueIdTodo - errors', () => {
      it('should have a postV3ProjectsIdIssuesIssueIdTodo function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdIssuesIssueIdTodo === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdTodo(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdTodo', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing issueId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesIssueIdTodo('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'issueId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesIssueIdTodo', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesNoteableIdNotes - errors', () => {
      it('should have a getV3ProjectsIdIssuesNoteableIdNotes function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdIssuesNoteableIdNotes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesNoteableIdNotes(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesNoteableIdNotes('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesNoteableIdNotes - errors', () => {
      it('should have a postV3ProjectsIdIssuesNoteableIdNotes function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdIssuesNoteableIdNotes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesNoteableIdNotes(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesNoteableIdNotes('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesNoteableIdNotes('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdIssuesNoteableIdNotesNoteId - errors', () => {
      it('should have a getV3ProjectsIdIssuesNoteableIdNotesNoteId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdIssuesNoteableIdNotesNoteId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesNoteableIdNotesNoteId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesNoteableIdNotesNoteId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdIssuesNoteableIdNotesNoteId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdIssuesNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdIssuesNoteableIdNotesNoteId - errors', () => {
      it('should have a putV3ProjectsIdIssuesNoteableIdNotesNoteId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdIssuesNoteableIdNotesNoteId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdIssuesNoteableIdNotesNoteId(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdIssuesNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdIssuesNoteableIdNotesNoteId('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdIssuesNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdIssuesNoteableIdNotesNoteId('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdIssuesNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdIssuesNoteableIdNotesNoteId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdIssuesNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdIssuesNoteableIdNotesNoteId - errors', () => {
      it('should have a deleteV3ProjectsIdIssuesNoteableIdNotesNoteId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdIssuesNoteableIdNotesNoteId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesNoteableIdNotesNoteId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesNoteableIdNotesNoteId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesNoteableIdNotesNoteId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdIssuesSubscribableIdSubscription - errors', () => {
      it('should have a postV3ProjectsIdIssuesSubscribableIdSubscription function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdIssuesSubscribableIdSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesSubscribableIdSubscription(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subscribableId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdIssuesSubscribableIdSubscription('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'subscribableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdIssuesSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdIssuesSubscribableIdSubscription - errors', () => {
      it('should have a deleteV3ProjectsIdIssuesSubscribableIdSubscription function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdIssuesSubscribableIdSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesSubscribableIdSubscription(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subscribableId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdIssuesSubscribableIdSubscription('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'subscribableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdIssuesSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdKeys - errors', () => {
      it('should have a getV3ProjectsIdKeys function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdKeys === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdKeys(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdKeys', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdKeys - errors', () => {
      it('should have a postV3ProjectsIdKeys function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdKeys === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdKeys(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdKeys', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdKeys('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdKeys', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdKeysKeyId - errors', () => {
      it('should have a getV3ProjectsIdKeysKeyId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdKeysKeyId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdKeysKeyId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdKeysKeyId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdKeysKeyId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'keyId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdKeysKeyId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdKeysKeyId - errors', () => {
      it('should have a deleteV3ProjectsIdKeysKeyId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdKeysKeyId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdKeysKeyId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdKeysKeyId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdKeysKeyId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'keyId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdKeysKeyId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdKeysKeyIdDisable - errors', () => {
      it('should have a deleteV3ProjectsIdKeysKeyIdDisable function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdKeysKeyIdDisable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdKeysKeyIdDisable(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdKeysKeyIdDisable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdKeysKeyIdDisable('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'keyId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdKeysKeyIdDisable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdKeysKeyIdEnable - errors', () => {
      it('should have a postV3ProjectsIdKeysKeyIdEnable function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdKeysKeyIdEnable === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdKeysKeyIdEnable(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdKeysKeyIdEnable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdKeysKeyIdEnable('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'keyId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdKeysKeyIdEnable', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdLabels - errors', () => {
      it('should have a getV3ProjectsIdLabels function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdLabels === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdLabels(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdLabels', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdLabels - errors', () => {
      it('should have a putV3ProjectsIdLabels function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdLabels === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdLabels(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdLabels', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdLabels('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdLabels', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdLabels - errors', () => {
      it('should have a postV3ProjectsIdLabels function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdLabels === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdLabels(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdLabels', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdLabels('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdLabels', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdLabels - errors', () => {
      it('should have a deleteV3ProjectsIdLabels function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdLabels === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdLabels(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdLabels', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdLabels('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'name is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdLabels', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdLabelsSubscribableIdSubscription - errors', () => {
      it('should have a postV3ProjectsIdLabelsSubscribableIdSubscription function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdLabelsSubscribableIdSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdLabelsSubscribableIdSubscription(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdLabelsSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subscribableId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdLabelsSubscribableIdSubscription('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'subscribableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdLabelsSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdLabelsSubscribableIdSubscription - errors', () => {
      it('should have a deleteV3ProjectsIdLabelsSubscribableIdSubscription function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdLabelsSubscribableIdSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdLabelsSubscribableIdSubscription(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdLabelsSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subscribableId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdLabelsSubscribableIdSubscription('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'subscribableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdLabelsSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMembers - errors', () => {
      it('should have a getV3ProjectsIdMembers function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMembers === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMembers(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMembers', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMembers - errors', () => {
      it('should have a postV3ProjectsIdMembers function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMembers === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMembers(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMembers', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMembers('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMembers', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMembersUserId - errors', () => {
      it('should have a getV3ProjectsIdMembersUserId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMembersUserId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMembersUserId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing userId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMembersUserId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'userId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMembersUserId - errors', () => {
      it('should have a putV3ProjectsIdMembersUserId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdMembersUserId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMembersUserId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing userId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMembersUserId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'userId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMembersUserId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMembersUserId - errors', () => {
      it('should have a deleteV3ProjectsIdMembersUserId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdMembersUserId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMembersUserId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing userId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMembersUserId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'userId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMembersUserId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestMergeRequestId - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestMergeRequestId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestMergeRequestId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestMergeRequestId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestMergeRequestId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMergeRequestMergeRequestId - errors', () => {
      it('should have a putV3ProjectsIdMergeRequestMergeRequestId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdMergeRequestMergeRequestId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestMergeRequestId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMergeRequestMergeRequestId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestMergeRequestId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMergeRequestMergeRequestId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestMergeRequestIdCancelMergeWhenBuildSucceeds - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestMergeRequestIdCancelMergeWhenBuildSucceeds function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestMergeRequestIdCancelMergeWhenBuildSucceeds === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestMergeRequestIdCancelMergeWhenBuildSucceeds(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestMergeRequestIdCancelMergeWhenBuildSucceeds', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestMergeRequestIdCancelMergeWhenBuildSucceeds('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestMergeRequestIdCancelMergeWhenBuildSucceeds', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestMergeRequestIdChanges - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestMergeRequestIdChanges function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestMergeRequestIdChanges === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestIdChanges(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestMergeRequestIdChanges', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestIdChanges('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestMergeRequestIdChanges', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestMergeRequestIdClosesIssues - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestMergeRequestIdClosesIssues function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestMergeRequestIdClosesIssues === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestIdClosesIssues(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestMergeRequestIdClosesIssues', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestIdClosesIssues('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestMergeRequestIdClosesIssues', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestMergeRequestIdComments - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestMergeRequestIdComments function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestMergeRequestIdComments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestIdComments(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestMergeRequestIdComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestIdComments('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestMergeRequestIdComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestMergeRequestIdComments - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestMergeRequestIdComments function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestMergeRequestIdComments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestMergeRequestIdComments(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestMergeRequestIdComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestMergeRequestIdComments('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestMergeRequestIdComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestMergeRequestIdComments('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestMergeRequestIdComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestMergeRequestIdCommits - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestMergeRequestIdCommits function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestMergeRequestIdCommits === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestIdCommits(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestMergeRequestIdCommits', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestMergeRequestIdCommits('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestMergeRequestIdCommits', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMergeRequestMergeRequestIdMerge - errors', () => {
      it('should have a putV3ProjectsIdMergeRequestMergeRequestIdMerge function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdMergeRequestMergeRequestIdMerge === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestMergeRequestIdMerge(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMergeRequestMergeRequestIdMerge', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestMergeRequestIdMerge('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMergeRequestMergeRequestIdMerge', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestSubscribableIdSubscription - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestSubscribableIdSubscription function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestSubscribableIdSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestSubscribableIdSubscription(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subscribableId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestSubscribableIdSubscription('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'subscribableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMergeRequestSubscribableIdSubscription - errors', () => {
      it('should have a deleteV3ProjectsIdMergeRequestSubscribableIdSubscription function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdMergeRequestSubscribableIdSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestSubscribableIdSubscription(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subscribableId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestSubscribableIdSubscription('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'subscribableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequests - errors', () => {
      it('should have a getV3ProjectsIdMergeRequests function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequests(null, null, null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequests - errors', () => {
      it('should have a postV3ProjectsIdMergeRequests function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequests === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequests(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequests('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequests', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestId - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsMergeRequestId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsMergeRequestId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMergeRequestsMergeRequestId - errors', () => {
      it('should have a putV3ProjectsIdMergeRequestsMergeRequestId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdMergeRequestsMergeRequestId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestsMergeRequestId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMergeRequestsMergeRequestId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestsMergeRequestId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMergeRequestsMergeRequestId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMergeRequestsMergeRequestId - errors', () => {
      it('should have a deleteV3ProjectsIdMergeRequestsMergeRequestId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdMergeRequestsMergeRequestId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsMergeRequestId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsMergeRequestId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsMergeRequestId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsMergeRequestId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdAddSpentTime - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestsMergeRequestIdAddSpentTime function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestsMergeRequestIdAddSpentTime === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdAddSpentTime(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdAddSpentTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdAddSpentTime('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdAddSpentTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdAddSpentTime('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdAddSpentTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing awardId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'awardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId - errors', () => {
      it('should have a deleteV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing awardId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'awardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsMergeRequestIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdCancelMergeWhenBuildSucceeds - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestsMergeRequestIdCancelMergeWhenBuildSucceeds function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestsMergeRequestIdCancelMergeWhenBuildSucceeds === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdCancelMergeWhenBuildSucceeds(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdCancelMergeWhenBuildSucceeds', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdCancelMergeWhenBuildSucceeds('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdCancelMergeWhenBuildSucceeds', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdChanges - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsMergeRequestIdChanges function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsMergeRequestIdChanges === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdChanges(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdChanges', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdChanges('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdChanges', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdClosesIssues - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsMergeRequestIdClosesIssues function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsMergeRequestIdClosesIssues === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdClosesIssues(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdClosesIssues', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdClosesIssues('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdClosesIssues', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdComments - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsMergeRequestIdComments function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsMergeRequestIdComments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdComments(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdComments('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdComments - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestsMergeRequestIdComments function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestsMergeRequestIdComments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdComments(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdComments('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdComments('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdCommits - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsMergeRequestIdCommits function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsMergeRequestIdCommits === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdCommits(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdCommits', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdCommits('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdCommits', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMergeRequestsMergeRequestIdMerge - errors', () => {
      it('should have a putV3ProjectsIdMergeRequestsMergeRequestIdMerge function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdMergeRequestsMergeRequestIdMerge === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestsMergeRequestIdMerge(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMergeRequestsMergeRequestIdMerge', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestsMergeRequestIdMerge('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMergeRequestsMergeRequestIdMerge', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing awardId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'awardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId - errors', () => {
      it('should have a deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing awardId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'awardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsMergeRequestIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdResetSpentTime - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestsMergeRequestIdResetSpentTime function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestsMergeRequestIdResetSpentTime === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdResetSpentTime(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdResetSpentTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdResetSpentTime('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdResetSpentTime', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdResetTimeEstimate - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestsMergeRequestIdResetTimeEstimate function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestsMergeRequestIdResetTimeEstimate === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdResetTimeEstimate(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdResetTimeEstimate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdResetTimeEstimate('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdResetTimeEstimate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdTimeEstimate - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestsMergeRequestIdTimeEstimate function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestsMergeRequestIdTimeEstimate === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdTimeEstimate(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdTimeEstimate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdTimeEstimate('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdTimeEstimate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdTimeEstimate('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdTimeEstimate', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdTimeStats - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsMergeRequestIdTimeStats function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsMergeRequestIdTimeStats === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdTimeStats(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdTimeStats', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdTimeStats('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdTimeStats', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsMergeRequestIdTodo - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestsMergeRequestIdTodo function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestsMergeRequestIdTodo === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdTodo(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdTodo', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsMergeRequestIdTodo('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsMergeRequestIdTodo', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdVersions - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsMergeRequestIdVersions function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsMergeRequestIdVersions === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdVersions(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdVersions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdVersions('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdVersions', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsMergeRequestIdVersionsVersionId - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsMergeRequestIdVersionsVersionId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsMergeRequestIdVersionsVersionId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdVersionsVersionId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdVersionsVersionId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing mergeRequestId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdVersionsVersionId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'mergeRequestId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdVersionsVersionId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing versionId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsMergeRequestIdVersionsVersionId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'versionId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsMergeRequestIdVersionsVersionId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsNoteableIdNotes - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsNoteableIdNotes function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsNoteableIdNotes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsNoteableIdNotes(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsNoteableIdNotes('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsNoteableIdNotes - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestsNoteableIdNotes function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestsNoteableIdNotes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsNoteableIdNotes(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsNoteableIdNotes('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsNoteableIdNotes('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMergeRequestsNoteableIdNotesNoteId - errors', () => {
      it('should have a getV3ProjectsIdMergeRequestsNoteableIdNotesNoteId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMergeRequestsNoteableIdNotesNoteId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsNoteableIdNotesNoteId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsNoteableIdNotesNoteId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMergeRequestsNoteableIdNotesNoteId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId - errors', () => {
      it('should have a putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMergeRequestsNoteableIdNotesNoteId - errors', () => {
      it('should have a deleteV3ProjectsIdMergeRequestsNoteableIdNotesNoteId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdMergeRequestsNoteableIdNotesNoteId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsNoteableIdNotesNoteId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsNoteableIdNotesNoteId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsNoteableIdNotesNoteId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMergeRequestsSubscribableIdSubscription - errors', () => {
      it('should have a postV3ProjectsIdMergeRequestsSubscribableIdSubscription function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMergeRequestsSubscribableIdSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsSubscribableIdSubscription(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subscribableId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMergeRequestsSubscribableIdSubscription('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'subscribableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMergeRequestsSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdMergeRequestsSubscribableIdSubscription - errors', () => {
      it('should have a deleteV3ProjectsIdMergeRequestsSubscribableIdSubscription function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdMergeRequestsSubscribableIdSubscription === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsSubscribableIdSubscription(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing subscribableId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdMergeRequestsSubscribableIdSubscription('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'subscribableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdMergeRequestsSubscribableIdSubscription', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMilestones - errors', () => {
      it('should have a getV3ProjectsIdMilestones function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMilestones === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMilestones(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMilestones', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdMilestones - errors', () => {
      it('should have a postV3ProjectsIdMilestones function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdMilestones === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMilestones(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMilestones', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdMilestones('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdMilestones', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMilestonesMilestoneId - errors', () => {
      it('should have a getV3ProjectsIdMilestonesMilestoneId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMilestonesMilestoneId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMilestonesMilestoneId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMilestonesMilestoneId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing milestoneId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMilestonesMilestoneId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'milestoneId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMilestonesMilestoneId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdMilestonesMilestoneId - errors', () => {
      it('should have a putV3ProjectsIdMilestonesMilestoneId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdMilestonesMilestoneId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMilestonesMilestoneId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMilestonesMilestoneId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing milestoneId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdMilestonesMilestoneId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'milestoneId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdMilestonesMilestoneId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdMilestonesMilestoneIdIssues - errors', () => {
      it('should have a getV3ProjectsIdMilestonesMilestoneIdIssues function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdMilestonesMilestoneIdIssues === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMilestonesMilestoneIdIssues(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMilestonesMilestoneIdIssues', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing milestoneId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdMilestonesMilestoneIdIssues('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'milestoneId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdMilestonesMilestoneIdIssues', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdNotificationSettings - errors', () => {
      it('should have a getV3ProjectsIdNotificationSettings function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdNotificationSettings === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdNotificationSettings(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdNotificationSettings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdNotificationSettings - errors', () => {
      it('should have a putV3ProjectsIdNotificationSettings function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdNotificationSettings === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdNotificationSettings(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdNotificationSettings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdPipeline - errors', () => {
      it('should have a postV3ProjectsIdPipeline function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdPipeline === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdPipeline(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdPipeline', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdPipeline('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdPipeline', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdPipelines - errors', () => {
      it('should have a getV3ProjectsIdPipelines function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdPipelines === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdPipelines(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdPipelines', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdPipelinesPipelineId - errors', () => {
      it('should have a getV3ProjectsIdPipelinesPipelineId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdPipelinesPipelineId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdPipelinesPipelineId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdPipelinesPipelineId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing pipelineId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdPipelinesPipelineId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'pipelineId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdPipelinesPipelineId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdPipelinesPipelineIdCancel - errors', () => {
      it('should have a postV3ProjectsIdPipelinesPipelineIdCancel function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdPipelinesPipelineIdCancel === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdPipelinesPipelineIdCancel(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdPipelinesPipelineIdCancel', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing pipelineId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdPipelinesPipelineIdCancel('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'pipelineId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdPipelinesPipelineIdCancel', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdPipelinesPipelineIdRetry - errors', () => {
      it('should have a postV3ProjectsIdPipelinesPipelineIdRetry function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdPipelinesPipelineIdRetry === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdPipelinesPipelineIdRetry(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdPipelinesPipelineIdRetry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing pipelineId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdPipelinesPipelineIdRetry('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'pipelineId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdPipelinesPipelineIdRetry', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryArchive - errors', () => {
      it('should have a getV3ProjectsIdRepositoryArchive function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryArchive === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryArchive(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryArchive', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryBlobsSha - errors', () => {
      it('should have a getV3ProjectsIdRepositoryBlobsSha function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryBlobsSha === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryBlobsSha(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryBlobsSha', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryBlobsSha('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'sha is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryBlobsSha', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing filepath', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryBlobsSha('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'filepath is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryBlobsSha', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryBranches - errors', () => {
      it('should have a getV3ProjectsIdRepositoryBranches function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryBranches === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryBranches(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryBranches', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryBranches - errors', () => {
      it('should have a postV3ProjectsIdRepositoryBranches function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdRepositoryBranches === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryBranches(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryBranches', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryBranches('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryBranches', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryBranchesBranch - errors', () => {
      it('should have a getV3ProjectsIdRepositoryBranchesBranch function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryBranchesBranch === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryBranchesBranch(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryBranchesBranch', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryBranchesBranch('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'branch is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryBranchesBranch', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdRepositoryBranchesBranch - errors', () => {
      it('should have a deleteV3ProjectsIdRepositoryBranchesBranch function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdRepositoryBranchesBranch === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryBranchesBranch(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdRepositoryBranchesBranch', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryBranchesBranch('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'branch is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdRepositoryBranchesBranch', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdRepositoryBranchesBranchProtect - errors', () => {
      it('should have a putV3ProjectsIdRepositoryBranchesBranchProtect function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdRepositoryBranchesBranchProtect === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryBranchesBranchProtect(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdRepositoryBranchesBranchProtect', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryBranchesBranchProtect('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'branch is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdRepositoryBranchesBranchProtect', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdRepositoryBranchesBranchUnprotect - errors', () => {
      it('should have a putV3ProjectsIdRepositoryBranchesBranchUnprotect function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdRepositoryBranchesBranchUnprotect === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryBranchesBranchUnprotect(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdRepositoryBranchesBranchUnprotect', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryBranchesBranchUnprotect('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'branch is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdRepositoryBranchesBranchUnprotect', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommits - errors', () => {
      it('should have a getV3ProjectsIdRepositoryCommits function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryCommits === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommits(null, null, null, null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommits', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryCommits - errors', () => {
      it('should have a postV3ProjectsIdRepositoryCommits function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdRepositoryCommits === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryCommits(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryCommits', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryCommits('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryCommits', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommitsSha - errors', () => {
      it('should have a getV3ProjectsIdRepositoryCommitsSha function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryCommitsSha === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsSha(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsSha', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsSha('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'sha is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsSha', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommitsShaBlob - errors', () => {
      it('should have a getV3ProjectsIdRepositoryCommitsShaBlob function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryCommitsShaBlob === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaBlob(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsShaBlob', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaBlob('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'sha is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsShaBlob', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing filepath', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaBlob('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'filepath is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsShaBlob', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommitsShaBuilds - errors', () => {
      it('should have a getV3ProjectsIdRepositoryCommitsShaBuilds function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryCommitsShaBuilds === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaBuilds(null, null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsShaBuilds', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaBuilds('fakeparam', null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'sha is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsShaBuilds', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryCommitsShaCherryPick - errors', () => {
      it('should have a postV3ProjectsIdRepositoryCommitsShaCherryPick function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdRepositoryCommitsShaCherryPick === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryCommitsShaCherryPick(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryCommitsShaCherryPick', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryCommitsShaCherryPick('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'sha is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryCommitsShaCherryPick', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryCommitsShaCherryPick('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryCommitsShaCherryPick', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommitsShaComments - errors', () => {
      it('should have a getV3ProjectsIdRepositoryCommitsShaComments function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryCommitsShaComments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaComments(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsShaComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaComments('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'sha is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsShaComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryCommitsShaComments - errors', () => {
      it('should have a postV3ProjectsIdRepositoryCommitsShaComments function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdRepositoryCommitsShaComments === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryCommitsShaComments(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryCommitsShaComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryCommitsShaComments('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'sha is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryCommitsShaComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryCommitsShaComments('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryCommitsShaComments', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommitsShaDiff - errors', () => {
      it('should have a getV3ProjectsIdRepositoryCommitsShaDiff function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryCommitsShaDiff === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaDiff(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsShaDiff', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaDiff('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'sha is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsShaDiff', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCommitsShaStatuses - errors', () => {
      it('should have a getV3ProjectsIdRepositoryCommitsShaStatuses function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryCommitsShaStatuses === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaStatuses(null, null, null, null, null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsShaStatuses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCommitsShaStatuses('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'sha is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCommitsShaStatuses', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryCompare - errors', () => {
      it('should have a getV3ProjectsIdRepositoryCompare function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryCompare === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCompare(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCompare', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing from', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCompare('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'from is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCompare', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing to', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryCompare('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'to is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryCompare', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryContributors - errors', () => {
      it('should have a getV3ProjectsIdRepositoryContributors function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryContributors === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryContributors(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryContributors', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryFiles - errors', () => {
      it('should have a getV3ProjectsIdRepositoryFiles function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryFiles === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryFiles(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryFiles', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing filePath', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryFiles('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'filePath is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryFiles', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryFiles('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'ref is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryFiles', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdRepositoryFiles - errors', () => {
      it('should have a putV3ProjectsIdRepositoryFiles function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdRepositoryFiles === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryFiles(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdRepositoryFiles', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryFiles('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdRepositoryFiles', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryFiles - errors', () => {
      it('should have a postV3ProjectsIdRepositoryFiles function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdRepositoryFiles === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryFiles(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryFiles', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryFiles('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryFiles', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdRepositoryFiles - errors', () => {
      it('should have a deleteV3ProjectsIdRepositoryFiles function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdRepositoryFiles === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryFiles(null, null, null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdRepositoryFiles', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing filePath', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryFiles('fakeparam', null, null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'filePath is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdRepositoryFiles', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing branchName', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryFiles('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'branchName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdRepositoryFiles', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing commitMessage', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryFiles('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'commitMessage is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdRepositoryFiles', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdRepositoryMergedBranches - errors', () => {
      it('should have a deleteV3ProjectsIdRepositoryMergedBranches function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdRepositoryMergedBranches === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryMergedBranches(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdRepositoryMergedBranches', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryRawBlobsSha - errors', () => {
      it('should have a getV3ProjectsIdRepositoryRawBlobsSha function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryRawBlobsSha === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryRawBlobsSha(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryRawBlobsSha', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryRawBlobsSha('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'sha is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryRawBlobsSha', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryTags - errors', () => {
      it('should have a getV3ProjectsIdRepositoryTags function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryTags === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryTags(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryTags - errors', () => {
      it('should have a postV3ProjectsIdRepositoryTags function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdRepositoryTags === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryTags(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryTags('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryTags', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryTagsTagName - errors', () => {
      it('should have a getV3ProjectsIdRepositoryTagsTagName function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryTagsTagName === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryTagsTagName(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryTagsTagName', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing tagName', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryTagsTagName('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'tagName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryTagsTagName', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdRepositoryTagsTagName - errors', () => {
      it('should have a deleteV3ProjectsIdRepositoryTagsTagName function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdRepositoryTagsTagName === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryTagsTagName(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdRepositoryTagsTagName', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing tagName', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRepositoryTagsTagName('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'tagName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdRepositoryTagsTagName', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdRepositoryTagsTagNameRelease - errors', () => {
      it('should have a putV3ProjectsIdRepositoryTagsTagNameRelease function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdRepositoryTagsTagNameRelease === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryTagsTagNameRelease(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdRepositoryTagsTagNameRelease', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing tagName', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryTagsTagNameRelease('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'tagName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdRepositoryTagsTagNameRelease', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdRepositoryTagsTagNameRelease('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdRepositoryTagsTagNameRelease', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRepositoryTagsTagNameRelease - errors', () => {
      it('should have a postV3ProjectsIdRepositoryTagsTagNameRelease function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdRepositoryTagsTagNameRelease === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryTagsTagNameRelease(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryTagsTagNameRelease', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing tagName', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryTagsTagNameRelease('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'tagName is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryTagsTagNameRelease', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRepositoryTagsTagNameRelease('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRepositoryTagsTagNameRelease', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRepositoryTree - errors', () => {
      it('should have a getV3ProjectsIdRepositoryTree function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRepositoryTree === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRepositoryTree(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRepositoryTree', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdRunners - errors', () => {
      it('should have a getV3ProjectsIdRunners function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdRunners === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdRunners(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdRunners', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdRunners - errors', () => {
      it('should have a postV3ProjectsIdRunners function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdRunners === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRunners(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRunners', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdRunners('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdRunners', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdRunnersRunnerId - errors', () => {
      it('should have a deleteV3ProjectsIdRunnersRunnerId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdRunnersRunnerId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRunnersRunnerId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdRunnersRunnerId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdRunnersRunnerId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'runnerId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdRunnersRunnerId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesAsana - errors', () => {
      it('should have a putV3ProjectsIdServicesAsana function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesAsana === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesAsana(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesAsana', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesAsana('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesAsana', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesAssembla - errors', () => {
      it('should have a putV3ProjectsIdServicesAssembla function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesAssembla === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesAssembla(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesAssembla', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesAssembla('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesAssembla', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesBamboo - errors', () => {
      it('should have a putV3ProjectsIdServicesBamboo function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesBamboo === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesBamboo(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesBamboo', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesBamboo('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesBamboo', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesBugzilla - errors', () => {
      it('should have a putV3ProjectsIdServicesBugzilla function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesBugzilla === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesBugzilla(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesBugzilla', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesBugzilla('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesBugzilla', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesBuildkite - errors', () => {
      it('should have a putV3ProjectsIdServicesBuildkite function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesBuildkite === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesBuildkite(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesBuildkite', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesBuildkite('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesBuildkite', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesBuildsEmail - errors', () => {
      it('should have a putV3ProjectsIdServicesBuildsEmail function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesBuildsEmail === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesBuildsEmail(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesBuildsEmail', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesBuildsEmail('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesBuildsEmail', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesCampfire - errors', () => {
      it('should have a putV3ProjectsIdServicesCampfire function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesCampfire === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesCampfire(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesCampfire', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesCampfire('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesCampfire', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesCustomIssueTracker - errors', () => {
      it('should have a putV3ProjectsIdServicesCustomIssueTracker function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesCustomIssueTracker === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesCustomIssueTracker(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesCustomIssueTracker', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesCustomIssueTracker('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesCustomIssueTracker', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesDroneCi - errors', () => {
      it('should have a putV3ProjectsIdServicesDroneCi function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesDroneCi === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesDroneCi(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesDroneCi', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesDroneCi('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesDroneCi', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesEmailsOnPush - errors', () => {
      it('should have a putV3ProjectsIdServicesEmailsOnPush function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesEmailsOnPush === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesEmailsOnPush(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesEmailsOnPush', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesEmailsOnPush('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesEmailsOnPush', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesExternalWiki - errors', () => {
      it('should have a putV3ProjectsIdServicesExternalWiki function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesExternalWiki === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesExternalWiki(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesExternalWiki', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesExternalWiki('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesExternalWiki', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesFlowdock - errors', () => {
      it('should have a putV3ProjectsIdServicesFlowdock function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesFlowdock === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesFlowdock(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesFlowdock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesFlowdock('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesFlowdock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesGemnasium - errors', () => {
      it('should have a putV3ProjectsIdServicesGemnasium function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesGemnasium === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesGemnasium(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesGemnasium', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesGemnasium('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesGemnasium', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesHipchat - errors', () => {
      it('should have a putV3ProjectsIdServicesHipchat function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesHipchat === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesHipchat(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesHipchat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesHipchat('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesHipchat', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesIrker - errors', () => {
      it('should have a putV3ProjectsIdServicesIrker function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesIrker === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesIrker(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesIrker', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesIrker('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesIrker', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesJira - errors', () => {
      it('should have a putV3ProjectsIdServicesJira function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesJira === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesJira(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesJira', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesJira('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesJira', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesKubernetes - errors', () => {
      it('should have a putV3ProjectsIdServicesKubernetes function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesKubernetes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesKubernetes(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesKubernetes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesKubernetes('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesKubernetes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesMattermost - errors', () => {
      it('should have a putV3ProjectsIdServicesMattermost function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesMattermost === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesMattermost(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesMattermost', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesMattermost('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesMattermost', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesMattermostSlashCommands - errors', () => {
      it('should have a putV3ProjectsIdServicesMattermostSlashCommands function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesMattermostSlashCommands === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesMattermostSlashCommands(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesMattermostSlashCommands', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesMattermostSlashCommands('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesMattermostSlashCommands', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdServicesMattermostSlashCommandsTrigger - errors', () => {
      it('should have a postV3ProjectsIdServicesMattermostSlashCommandsTrigger function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdServicesMattermostSlashCommandsTrigger === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdServicesMattermostSlashCommandsTrigger(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdServicesMattermostSlashCommandsTrigger', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdServicesMattermostSlashCommandsTrigger('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdServicesMattermostSlashCommandsTrigger', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesPipelinesEmail - errors', () => {
      it('should have a putV3ProjectsIdServicesPipelinesEmail function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesPipelinesEmail === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesPipelinesEmail(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesPipelinesEmail', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesPipelinesEmail('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesPipelinesEmail', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesPivotaltracker - errors', () => {
      it('should have a putV3ProjectsIdServicesPivotaltracker function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesPivotaltracker === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesPivotaltracker(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesPivotaltracker', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesPivotaltracker('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesPivotaltracker', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesPushover - errors', () => {
      it('should have a putV3ProjectsIdServicesPushover function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesPushover === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesPushover(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesPushover', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesPushover('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesPushover', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesRedmine - errors', () => {
      it('should have a putV3ProjectsIdServicesRedmine function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesRedmine === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesRedmine(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesRedmine', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesRedmine('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesRedmine', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesSlack - errors', () => {
      it('should have a putV3ProjectsIdServicesSlack function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesSlack === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesSlack(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesSlack', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesSlack('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesSlack', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesSlackSlashCommands - errors', () => {
      it('should have a putV3ProjectsIdServicesSlackSlashCommands function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesSlackSlashCommands === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesSlackSlashCommands(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesSlackSlashCommands', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesSlackSlashCommands('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesSlackSlashCommands', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdServicesSlackSlashCommandsTrigger - errors', () => {
      it('should have a postV3ProjectsIdServicesSlackSlashCommandsTrigger function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdServicesSlackSlashCommandsTrigger === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdServicesSlackSlashCommandsTrigger(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdServicesSlackSlashCommandsTrigger', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdServicesSlackSlashCommandsTrigger('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdServicesSlackSlashCommandsTrigger', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdServicesTeamcity - errors', () => {
      it('should have a putV3ProjectsIdServicesTeamcity function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdServicesTeamcity === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesTeamcity(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesTeamcity', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdServicesTeamcity('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdServicesTeamcity', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdServicesServiceSlug - errors', () => {
      it('should have a getV3ProjectsIdServicesServiceSlug function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdServicesServiceSlug === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing serviceSlug', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdServicesServiceSlug(null, null, (data, error) => {
            resolve(data);
            const displayE = 'serviceSlug is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdServicesServiceSlug', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdServicesServiceSlug('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdServicesServiceSlug', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdServicesServiceSlug - errors', () => {
      it('should have a deleteV3ProjectsIdServicesServiceSlug function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdServicesServiceSlug === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing serviceSlug', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdServicesServiceSlug(null, null, (data, error) => {
            resolve(data);
            const displayE = 'serviceSlug is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdServicesServiceSlug', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdServicesServiceSlug('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdServicesServiceSlug', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdShare - errors', () => {
      it('should have a postV3ProjectsIdShare function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdShare === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdShare(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdShare', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdShare('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdShare', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdShareGroupId - errors', () => {
      it('should have a deleteV3ProjectsIdShareGroupId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdShareGroupId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdShareGroupId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdShareGroupId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing groupId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdShareGroupId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'groupId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdShareGroupId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippets - errors', () => {
      it('should have a getV3ProjectsIdSnippets function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdSnippets === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippets(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdSnippets - errors', () => {
      it('should have a postV3ProjectsIdSnippets function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdSnippets === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippets(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdSnippets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippets('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdSnippets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsNoteableIdNotes - errors', () => {
      it('should have a getV3ProjectsIdSnippetsNoteableIdNotes function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdSnippetsNoteableIdNotes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsNoteableIdNotes(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsNoteableIdNotes('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdSnippetsNoteableIdNotes - errors', () => {
      it('should have a postV3ProjectsIdSnippetsNoteableIdNotes function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdSnippetsNoteableIdNotes === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsNoteableIdNotes(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdSnippetsNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsNoteableIdNotes('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdSnippetsNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsNoteableIdNotes('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdSnippetsNoteableIdNotes', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsNoteableIdNotesNoteId - errors', () => {
      it('should have a getV3ProjectsIdSnippetsNoteableIdNotesNoteId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdSnippetsNoteableIdNotesNoteId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsNoteableIdNotesNoteId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsNoteableIdNotesNoteId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsNoteableIdNotesNoteId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdSnippetsNoteableIdNotesNoteId - errors', () => {
      it('should have a putV3ProjectsIdSnippetsNoteableIdNotesNoteId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdSnippetsNoteableIdNotesNoteId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdSnippetsNoteableIdNotesNoteId(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdSnippetsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdSnippetsNoteableIdNotesNoteId('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdSnippetsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdSnippetsNoteableIdNotesNoteId('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdSnippetsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdSnippetsNoteableIdNotesNoteId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdSnippetsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdSnippetsNoteableIdNotesNoteId - errors', () => {
      it('should have a deleteV3ProjectsIdSnippetsNoteableIdNotesNoteId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdSnippetsNoteableIdNotesNoteId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsNoteableIdNotesNoteId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdSnippetsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteableId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsNoteableIdNotesNoteId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteableId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdSnippetsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsNoteableIdNotesNoteId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdSnippetsNoteableIdNotesNoteId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsSnippetId - errors', () => {
      it('should have a getV3ProjectsIdSnippetsSnippetId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdSnippetsSnippetId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snippetId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'snippetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdSnippetsSnippetId - errors', () => {
      it('should have a putV3ProjectsIdSnippetsSnippetId function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdSnippetsSnippetId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdSnippetsSnippetId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdSnippetsSnippetId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snippetId', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdSnippetsSnippetId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'snippetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdSnippetsSnippetId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdSnippetsSnippetId - errors', () => {
      it('should have a deleteV3ProjectsIdSnippetsSnippetId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdSnippetsSnippetId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsSnippetId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdSnippetsSnippetId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snippetId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsSnippetId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'snippetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdSnippetsSnippetId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsSnippetIdAwardEmoji - errors', () => {
      it('should have a getV3ProjectsIdSnippetsSnippetIdAwardEmoji function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdSnippetsSnippetIdAwardEmoji === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdAwardEmoji(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snippetId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdAwardEmoji('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'snippetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdSnippetsSnippetIdAwardEmoji - errors', () => {
      it('should have a postV3ProjectsIdSnippetsSnippetIdAwardEmoji function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdSnippetsSnippetIdAwardEmoji === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsSnippetIdAwardEmoji(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdSnippetsSnippetIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snippetId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsSnippetIdAwardEmoji('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'snippetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdSnippetsSnippetIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsSnippetIdAwardEmoji('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdSnippetsSnippetIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId - errors', () => {
      it('should have a getV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing awardId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'awardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snippetId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'snippetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId - errors', () => {
      it('should have a deleteV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing awardId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'awardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snippetId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'snippetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdSnippetsSnippetIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji - errors', () => {
      it('should have a getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snippetId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'snippetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji - errors', () => {
      it('should have a postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snippetId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'snippetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmoji', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId - errors', () => {
      it('should have a getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing awardId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'awardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snippetId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'snippetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId - errors', () => {
      it('should have a deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing awardId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'awardId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId('fakeparam', null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snippetId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId('fakeparam', 'fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'snippetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing noteId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'noteId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdSnippetsSnippetIdNotesNoteIdAwardEmojiAwardId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdSnippetsSnippetIdRaw - errors', () => {
      it('should have a getV3ProjectsIdSnippetsSnippetIdRaw function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdSnippetsSnippetIdRaw === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdRaw(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdRaw', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing snippetId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdSnippetsSnippetIdRaw('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'snippetId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdSnippetsSnippetIdRaw', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdStar - errors', () => {
      it('should have a postV3ProjectsIdStar function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdStar === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdStar(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdStar', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdStar - errors', () => {
      it('should have a deleteV3ProjectsIdStar function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdStar === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdStar(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdStar', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdStatusesSha - errors', () => {
      it('should have a postV3ProjectsIdStatusesSha function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdStatusesSha === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdStatusesSha(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdStatusesSha', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdStatusesSha('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'sha is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdStatusesSha', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdStatusesSha('fakeparam', 'fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdStatusesSha', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdTriggers - errors', () => {
      it('should have a getV3ProjectsIdTriggers function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdTriggers === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdTriggers(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdTriggers', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdTriggers - errors', () => {
      it('should have a postV3ProjectsIdTriggers function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdTriggers === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdTriggers(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdTriggers', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdTriggersToken - errors', () => {
      it('should have a getV3ProjectsIdTriggersToken function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdTriggersToken === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdTriggersToken(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdTriggersToken', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing token', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdTriggersToken('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'token is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdTriggersToken', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdTriggersToken - errors', () => {
      it('should have a deleteV3ProjectsIdTriggersToken function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdTriggersToken === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdTriggersToken(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdTriggersToken', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing token', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdTriggersToken('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'token is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdTriggersToken', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdUnarchive - errors', () => {
      it('should have a postV3ProjectsIdUnarchive function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdUnarchive === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdUnarchive(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdUnarchive', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdUploads - errors', () => {
      it('should have a postV3ProjectsIdUploads function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdUploads === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdUploads(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdUploads', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdUploads('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdUploads', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdUsers - errors', () => {
      it('should have a getV3ProjectsIdUsers function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdUsers === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdUsers(null, null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdUsers', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdVariables - errors', () => {
      it('should have a getV3ProjectsIdVariables function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdVariables === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdVariables(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdVariables', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3ProjectsIdVariables - errors', () => {
      it('should have a postV3ProjectsIdVariables function', (done) => {
        assert.equal(true, typeof a.postV3ProjectsIdVariables === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdVariables(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdVariables', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3ProjectsIdVariables('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3ProjectsIdVariables', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ProjectsIdVariablesKey - errors', () => {
      it('should have a getV3ProjectsIdVariablesKey function', (done) => {
        assert.equal(true, typeof a.getV3ProjectsIdVariablesKey === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdVariablesKey(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdVariablesKey', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing key', (done) => {
        const p = new Promise((resolve) => {
          a.getV3ProjectsIdVariablesKey('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'key is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3ProjectsIdVariablesKey', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3ProjectsIdVariablesKey - errors', () => {
      it('should have a putV3ProjectsIdVariablesKey function', (done) => {
        assert.equal(true, typeof a.putV3ProjectsIdVariablesKey === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdVariablesKey(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdVariablesKey', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing key', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ProjectsIdVariablesKey('fakeparam', null, null, (data, error) => {
            resolve(data);
            const displayE = 'key is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ProjectsIdVariablesKey', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3ProjectsIdVariablesKey - errors', () => {
      it('should have a deleteV3ProjectsIdVariablesKey function', (done) => {
        assert.equal(true, typeof a.deleteV3ProjectsIdVariablesKey === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdVariablesKey(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdVariablesKey', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing key', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3ProjectsIdVariablesKey('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'key is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3ProjectsIdVariablesKey', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3InternalAllowed - errors', () => {
      it('should have a postV3InternalAllowed function', (done) => {
        assert.equal(true, typeof a.postV3InternalAllowed === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3InternalBroadcastMessage - errors', () => {
      it('should have a getV3InternalBroadcastMessage function', (done) => {
        assert.equal(true, typeof a.getV3InternalBroadcastMessage === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3InternalCheck - errors', () => {
      it('should have a getV3InternalCheck function', (done) => {
        assert.equal(true, typeof a.getV3InternalCheck === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3InternalDiscover - errors', () => {
      it('should have a getV3InternalDiscover function', (done) => {
        assert.equal(true, typeof a.getV3InternalDiscover === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#postV3InternalLfsAuthenticate - errors', () => {
      it('should have a postV3InternalLfsAuthenticate function', (done) => {
        assert.equal(true, typeof a.postV3InternalLfsAuthenticate === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3InternalMergeRequestUrls - errors', () => {
      it('should have a getV3InternalMergeRequestUrls function', (done) => {
        assert.equal(true, typeof a.getV3InternalMergeRequestUrls === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#postV3InternalTwoFactorRecoveryCodes - errors', () => {
      it('should have a postV3InternalTwoFactorRecoveryCodes function', (done) => {
        assert.equal(true, typeof a.postV3InternalTwoFactorRecoveryCodes === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3Issues - errors', () => {
      it('should have a getV3Issues function', (done) => {
        assert.equal(true, typeof a.getV3Issues === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3KeysId - errors', () => {
      it('should have a getV3KeysId function', (done) => {
        assert.equal(true, typeof a.getV3KeysId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3KeysId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3KeysId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3CiLint - errors', () => {
      it('should have a postV3CiLint function', (done) => {
        assert.equal(true, typeof a.postV3CiLint === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3CiLint(null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3CiLint', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Namespaces - errors', () => {
      it('should have a getV3Namespaces function', (done) => {
        assert.equal(true, typeof a.getV3Namespaces === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3NotificationSettings - errors', () => {
      it('should have a getV3NotificationSettings function', (done) => {
        assert.equal(true, typeof a.getV3NotificationSettings === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#putV3NotificationSettings - errors', () => {
      it('should have a putV3NotificationSettings function', (done) => {
        assert.equal(true, typeof a.putV3NotificationSettings === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3Runners - errors', () => {
      it('should have a getV3Runners function', (done) => {
        assert.equal(true, typeof a.getV3Runners === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3RunnersAll - errors', () => {
      it('should have a getV3RunnersAll function', (done) => {
        assert.equal(true, typeof a.getV3RunnersAll === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3RunnersId - errors', () => {
      it('should have a getV3RunnersId function', (done) => {
        assert.equal(true, typeof a.getV3RunnersId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3RunnersId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3RunnersId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3RunnersId - errors', () => {
      it('should have a putV3RunnersId function', (done) => {
        assert.equal(true, typeof a.putV3RunnersId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3RunnersId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3RunnersId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3RunnersId - errors', () => {
      it('should have a deleteV3RunnersId function', (done) => {
        assert.equal(true, typeof a.deleteV3RunnersId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3RunnersId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3RunnersId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Snippets - errors', () => {
      it('should have a getV3Snippets function', (done) => {
        assert.equal(true, typeof a.getV3Snippets === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#postV3Snippets - errors', () => {
      it('should have a postV3Snippets function', (done) => {
        assert.equal(true, typeof a.postV3Snippets === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3Snippets(null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3Snippets', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3SnippetsPublic - errors', () => {
      it('should have a getV3SnippetsPublic function', (done) => {
        assert.equal(true, typeof a.getV3SnippetsPublic === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3SnippetsId - errors', () => {
      it('should have a getV3SnippetsId function', (done) => {
        assert.equal(true, typeof a.getV3SnippetsId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3SnippetsId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3SnippetsId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3SnippetsId - errors', () => {
      it('should have a putV3SnippetsId function', (done) => {
        assert.equal(true, typeof a.putV3SnippetsId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3SnippetsId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3SnippetsId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3SnippetsId - errors', () => {
      it('should have a deleteV3SnippetsId function', (done) => {
        assert.equal(true, typeof a.deleteV3SnippetsId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3SnippetsId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3SnippetsId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3SnippetsIdRaw - errors', () => {
      it('should have a getV3SnippetsIdRaw function', (done) => {
        assert.equal(true, typeof a.getV3SnippetsIdRaw === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3SnippetsIdRaw(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3SnippetsIdRaw', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Hooks - errors', () => {
      it('should have a getV3Hooks function', (done) => {
        assert.equal(true, typeof a.getV3Hooks === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#postV3Hooks - errors', () => {
      it('should have a postV3Hooks function', (done) => {
        assert.equal(true, typeof a.postV3Hooks === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3Hooks(null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3Hooks', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3HooksId - errors', () => {
      it('should have a getV3HooksId function', (done) => {
        assert.equal(true, typeof a.getV3HooksId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3HooksId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3HooksId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3HooksId - errors', () => {
      it('should have a deleteV3HooksId function', (done) => {
        assert.equal(true, typeof a.deleteV3HooksId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3HooksId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3HooksId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Todos - errors', () => {
      it('should have a getV3Todos function', (done) => {
        assert.equal(true, typeof a.getV3Todos === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3Todos - errors', () => {
      it('should have a deleteV3Todos function', (done) => {
        assert.equal(true, typeof a.deleteV3Todos === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3TodosId - errors', () => {
      it('should have a deleteV3TodosId function', (done) => {
        assert.equal(true, typeof a.deleteV3TodosId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3TodosId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3TodosId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Users - errors', () => {
      it('should have a getV3Users function', (done) => {
        assert.equal(true, typeof a.getV3Users === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#postV3Users - errors', () => {
      it('should have a postV3Users function', (done) => {
        assert.equal(true, typeof a.postV3Users === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3Users(null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3Users', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UsersId - errors', () => {
      it('should have a getV3UsersId function', (done) => {
        assert.equal(true, typeof a.getV3UsersId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UsersId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3UsersId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3UsersId - errors', () => {
      it('should have a putV3UsersId function', (done) => {
        assert.equal(true, typeof a.putV3UsersId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3UsersId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3UsersId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3UsersId - errors', () => {
      it('should have a deleteV3UsersId function', (done) => {
        assert.equal(true, typeof a.deleteV3UsersId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3UsersId(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3UsersId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3UsersIdBlock - errors', () => {
      it('should have a putV3UsersIdBlock function', (done) => {
        assert.equal(true, typeof a.putV3UsersIdBlock === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3UsersIdBlock(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3UsersIdBlock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UsersIdEmails - errors', () => {
      it('should have a getV3UsersIdEmails function', (done) => {
        assert.equal(true, typeof a.getV3UsersIdEmails === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UsersIdEmails(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3UsersIdEmails', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3UsersIdEmails - errors', () => {
      it('should have a postV3UsersIdEmails function', (done) => {
        assert.equal(true, typeof a.postV3UsersIdEmails === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3UsersIdEmails(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3UsersIdEmails', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3UsersIdEmails('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3UsersIdEmails', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3UsersIdEmailsEmailId - errors', () => {
      it('should have a deleteV3UsersIdEmailsEmailId function', (done) => {
        assert.equal(true, typeof a.deleteV3UsersIdEmailsEmailId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3UsersIdEmailsEmailId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3UsersIdEmailsEmailId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing emailId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3UsersIdEmailsEmailId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'emailId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3UsersIdEmailsEmailId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UsersIdEvents - errors', () => {
      it('should have a getV3UsersIdEvents function', (done) => {
        assert.equal(true, typeof a.getV3UsersIdEvents === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UsersIdEvents(null, null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3UsersIdEvents', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UsersIdKeys - errors', () => {
      it('should have a getV3UsersIdKeys function', (done) => {
        assert.equal(true, typeof a.getV3UsersIdKeys === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UsersIdKeys(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3UsersIdKeys', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#postV3UsersIdKeys - errors', () => {
      it('should have a postV3UsersIdKeys function', (done) => {
        assert.equal(true, typeof a.postV3UsersIdKeys === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.postV3UsersIdKeys(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3UsersIdKeys', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3UsersIdKeys('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3UsersIdKeys', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3UsersIdKeysKeyId - errors', () => {
      it('should have a deleteV3UsersIdKeysKeyId function', (done) => {
        assert.equal(true, typeof a.deleteV3UsersIdKeysKeyId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3UsersIdKeysKeyId(null, null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3UsersIdKeysKeyId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3UsersIdKeysKeyId('fakeparam', null, (data, error) => {
            resolve(data);
            const displayE = 'keyId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3UsersIdKeysKeyId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#putV3UsersIdUnblock - errors', () => {
      it('should have a putV3UsersIdUnblock function', (done) => {
        assert.equal(true, typeof a.putV3UsersIdUnblock === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        const p = new Promise((resolve) => {
          a.putV3UsersIdUnblock(null, (data, error) => {
            resolve(data);
            const displayE = 'id is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3UsersIdUnblock', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3User - errors', () => {
      it('should have a getV3User function', (done) => {
        assert.equal(true, typeof a.getV3User === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3UserEmails - errors', () => {
      it('should have a getV3UserEmails function', (done) => {
        assert.equal(true, typeof a.getV3UserEmails === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#postV3UserEmails - errors', () => {
      it('should have a postV3UserEmails function', (done) => {
        assert.equal(true, typeof a.postV3UserEmails === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3UserEmails(null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3UserEmails', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UserEmailsEmailId - errors', () => {
      it('should have a getV3UserEmailsEmailId function', (done) => {
        assert.equal(true, typeof a.getV3UserEmailsEmailId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing emailId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UserEmailsEmailId(null, (data, error) => {
            resolve(data);
            const displayE = 'emailId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3UserEmailsEmailId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3UserEmailsEmailId - errors', () => {
      it('should have a deleteV3UserEmailsEmailId function', (done) => {
        assert.equal(true, typeof a.deleteV3UserEmailsEmailId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing emailId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3UserEmailsEmailId(null, (data, error) => {
            resolve(data);
            const displayE = 'emailId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3UserEmailsEmailId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UserKeys - errors', () => {
      it('should have a getV3UserKeys function', (done) => {
        assert.equal(true, typeof a.getV3UserKeys === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#postV3UserKeys - errors', () => {
      it('should have a postV3UserKeys function', (done) => {
        assert.equal(true, typeof a.postV3UserKeys === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3UserKeys(null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3UserKeys', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3UserKeysKeyId - errors', () => {
      it('should have a getV3UserKeysKeyId function', (done) => {
        assert.equal(true, typeof a.getV3UserKeysKeyId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        const p = new Promise((resolve) => {
          a.getV3UserKeysKeyId(null, (data, error) => {
            resolve(data);
            const displayE = 'keyId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3UserKeysKeyId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#deleteV3UserKeysKeyId - errors', () => {
      it('should have a deleteV3UserKeysKeyId function', (done) => {
        assert.equal(true, typeof a.deleteV3UserKeysKeyId === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        const p = new Promise((resolve) => {
          a.deleteV3UserKeysKeyId(null, (data, error) => {
            resolve(data);
            const displayE = 'keyId is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-deleteV3UserKeysKeyId', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3DeployKeys - errors', () => {
      it('should have a getV3DeployKeys function', (done) => {
        assert.equal(true, typeof a.getV3DeployKeys === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#postV3Session - errors', () => {
      it('should have a postV3Session function', (done) => {
        assert.equal(true, typeof a.postV3Session === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.postV3Session(null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-postV3Session', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3ApplicationSettings - errors', () => {
      it('should have a getV3ApplicationSettings function', (done) => {
        assert.equal(true, typeof a.getV3ApplicationSettings === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#putV3ApplicationSettings - errors', () => {
      it('should have a putV3ApplicationSettings function', (done) => {
        assert.equal(true, typeof a.putV3ApplicationSettings === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        const p = new Promise((resolve) => {
          a.putV3ApplicationSettings(null, (data, error) => {
            resolve(data);
            const displayE = 'body is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-putV3ApplicationSettings', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3SidekiqCompoundMetrics - errors', () => {
      it('should have a getV3SidekiqCompoundMetrics function', (done) => {
        assert.equal(true, typeof a.getV3SidekiqCompoundMetrics === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3SidekiqJobStats - errors', () => {
      it('should have a getV3SidekiqJobStats function', (done) => {
        assert.equal(true, typeof a.getV3SidekiqJobStats === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3SidekiqProcessMetrics - errors', () => {
      it('should have a getV3SidekiqProcessMetrics function', (done) => {
        assert.equal(true, typeof a.getV3SidekiqProcessMetrics === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3SidekiqQueueMetrics - errors', () => {
      it('should have a getV3SidekiqQueueMetrics function', (done) => {
        assert.equal(true, typeof a.getV3SidekiqQueueMetrics === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3Licenses - errors', () => {
      it('should have a getV3Licenses function', (done) => {
        assert.equal(true, typeof a.getV3Licenses === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3LicensesName - errors', () => {
      it('should have a getV3LicensesName function', (done) => {
        assert.equal(true, typeof a.getV3LicensesName === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        const p = new Promise((resolve) => {
          a.getV3LicensesName(null, (data, error) => {
            resolve(data);
            const displayE = 'name is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3LicensesName', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesDockerfiles - errors', () => {
      it('should have a getV3TemplatesDockerfiles function', (done) => {
        assert.equal(true, typeof a.getV3TemplatesDockerfiles === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesDockerfilesName - errors', () => {
      it('should have a getV3TemplatesDockerfilesName function', (done) => {
        assert.equal(true, typeof a.getV3TemplatesDockerfilesName === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        const p = new Promise((resolve) => {
          a.getV3TemplatesDockerfilesName(null, (data, error) => {
            resolve(data);
            const displayE = 'name is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3TemplatesDockerfilesName', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesGitignores - errors', () => {
      it('should have a getV3TemplatesGitignores function', (done) => {
        assert.equal(true, typeof a.getV3TemplatesGitignores === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesGitignoresName - errors', () => {
      it('should have a getV3TemplatesGitignoresName function', (done) => {
        assert.equal(true, typeof a.getV3TemplatesGitignoresName === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        const p = new Promise((resolve) => {
          a.getV3TemplatesGitignoresName(null, (data, error) => {
            resolve(data);
            const displayE = 'name is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3TemplatesGitignoresName', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesGitlabCiYmls - errors', () => {
      it('should have a getV3TemplatesGitlabCiYmls function', (done) => {
        assert.equal(true, typeof a.getV3TemplatesGitlabCiYmls === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesGitlabCiYmlsName - errors', () => {
      it('should have a getV3TemplatesGitlabCiYmlsName function', (done) => {
        assert.equal(true, typeof a.getV3TemplatesGitlabCiYmlsName === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        const p = new Promise((resolve) => {
          a.getV3TemplatesGitlabCiYmlsName(null, (data, error) => {
            resolve(data);
            const displayE = 'name is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3TemplatesGitlabCiYmlsName', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesLicenses - errors', () => {
      it('should have a getV3TemplatesLicenses function', (done) => {
        assert.equal(true, typeof a.getV3TemplatesLicenses === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3TemplatesLicensesName - errors', () => {
      it('should have a getV3TemplatesLicensesName function', (done) => {
        assert.equal(true, typeof a.getV3TemplatesLicensesName === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        const p = new Promise((resolve) => {
          a.getV3TemplatesLicensesName(null, (data, error) => {
            resolve(data);
            const displayE = 'name is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3TemplatesLicensesName', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Gitignores - errors', () => {
      it('should have a getV3Gitignores function', (done) => {
        assert.equal(true, typeof a.getV3Gitignores === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3GitignoresName - errors', () => {
      it('should have a getV3GitignoresName function', (done) => {
        assert.equal(true, typeof a.getV3GitignoresName === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GitignoresName(null, (data, error) => {
            resolve(data);
            const displayE = 'name is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3GitignoresName', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3GitlabCiYmls - errors', () => {
      it('should have a getV3GitlabCiYmls function', (done) => {
        assert.equal(true, typeof a.getV3GitlabCiYmls === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3GitlabCiYmlsName - errors', () => {
      it('should have a getV3GitlabCiYmlsName function', (done) => {
        assert.equal(true, typeof a.getV3GitlabCiYmlsName === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        const p = new Promise((resolve) => {
          a.getV3GitlabCiYmlsName(null, (data, error) => {
            resolve(data);
            const displayE = 'name is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3GitlabCiYmlsName', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Dockerfiles - errors', () => {
      it('should have a getV3Dockerfiles function', (done) => {
        assert.equal(true, typeof a.getV3Dockerfiles === 'function');
        done();
      }).timeout(attemptTimeout);
    });

    describe('#getV3DockerfilesName - errors', () => {
      it('should have a getV3DockerfilesName function', (done) => {
        assert.equal(true, typeof a.getV3DockerfilesName === 'function');
        done();
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        const p = new Promise((resolve) => {
          a.getV3DockerfilesName(null, (data, error) => {
            resolve(data);
            const displayE = 'name is required';
            runErrorAsserts(data, error, 'AD.300', 'Test-gitlab-adapter-getV3DockerfilesName', displayE);
            resolve(data);
            done();
          });
        });
        // log just done to get rid of const lint issue!
        log.debug(p);
      }).timeout(attemptTimeout);
    });

    describe('#getV3Version - errors', () => {
      it('should have a getV3Version function', (done) => {
        assert.equal(true, typeof a.getV3Version === 'function');
        done();
      }).timeout(attemptTimeout);
    });
  });
});
